clc;clear

%% Decoding of MATCH vs. MISMATCH 

% For each brain region that presents more than 'min_electrodes' # of electrodes, 
% it selects at every iterations ('n_times'), 'take_electrodes', and do
% 'n_folds'-cross-validation. At every validation, data is divided in train
% and test and results of test are saved. 
% For all electrodes selected at each iteration, it concatenates the time
% response of these electrodes. I select PCA ('do_PCA'), it computes a PCA over 
% the concatenated signal. It selects the number of features that explain
% 'n_explaineds' of the variance.
%
% Save the results in the folder 'D01_decoding_tile_(1/2)'

%% Select params

% binary classification, save data for each category
tile = '1'; % IMPORTANT, WRITE AS CHART!
frequency_band = 'gamma';
select = 1; % 1 for power, 2 for auc
min_electrodes = 12; % min # of electrodes to consider region
take_electrodes = 0; % # of channels to take for the analysis, if 0 take all
do_pca = true; 
n_times = 200;
n_folds = 5;
n_explaineds = [70];
ifNormalize = false; % if normalize signal
randomize = false; % if randomize label

%%

folder = ['P05_group_regions_tile_' tile '/' frequency_band '/']; % folder with region data
folder_results = ['D01_decoding_tile_' tile '/' frequency_band '/']; % where to save results
mkdir(folder_results)

regions = dir(folder);
results = struct;

for n_exp = 1:length(n_explaineds)
    
    n_explained = n_explaineds(n_exp);
    n_results = 1;
    
    for n_reg = 1:length(regions)-2 % for each region

        name = regions(n_reg+2).name;
        region_name = name(1:end-4);

        load([folder name])

        category_1 = {};
        category_2 = {};
        i_ch = 1;
        min_trials1 = [];
        min_trials2 = [];

        n_channels = sum([data.number]);

        if n_channels>=min_electrodes % if this region has more channels that indicated

            for n_sub = 1:length(data)

                subject = data(n_sub).subject;

                load(fullfile('P00_data_behavior','b_data_subject_'+string(subject)+'.mat'));

                artifacts = data(n_sub).artifacts;

                match = b_data(1).x; 
                response = match; response(artifacts) = [];
                power = data(n_sub).power; power(artifacts,:,:) = [];
                auc = data(n_sub).auc; auc(artifacts,:) = [];

                % organize data by categories
                take1 = (response == 1);
                take2 = (response == 0);


                % if selecting the power
                if select == 1
                    for n_ch = 1:size(power, 3) % take data for each channel
                        category_1{i_ch} = power(take1, :, n_ch);
                        category_2{i_ch} = power(take2, :, n_ch);

                        min_trials1 = [min_trials1, sum(take1)];
                        min_trials2 = [min_trials2, sum(take2)];

                        i_ch = i_ch + 1;
                    end
                else % take AUC
                    for n_ch = 1:size(power, 3)
                        category_1{i_ch} = auc(take1, n_ch);
                        category_2{i_ch} = auc(take2, n_ch);
                        i_ch = i_ch + 1;
                    end
                end

            end

            % create X and Y variables for training
            % taking all channels

            accuracies = [];
            n_comp = [];

            for n_t = 1:n_times
                % Concatenate results to create X variable, randsampling to equalize number
                % of match and mismatch trials
                rng(n_t)
                % randsample # of electrodes to take
                if take_electrodes == 0
                    select_ch = [1:length(category_1)];
                else
                    select_ch = randsample(length(category_1), take_electrodes);
                end

                % take the min number of trials considering the channels
                % selected
                min_trials_take1 = min(min_trials1(select_ch));
                min_trials_take2 = min(min_trials2(select_ch));
                min_trials_take = min([min_trials_take1, min_trials_take2]);

                X = [];
                for n_ch = 1:length(select_ch) % take selected electrodes

                    x1 = category_1{select_ch(n_ch)};
                    x2 = category_2{select_ch(n_ch)};
                    select1 = randsample(size(x1,1), min_trials_take);
                    select2 = randsample(size(x2,1), min_trials_take);

                    x0 = [x1(select1, :); x2(select2, :)];
                    if ifNormalize
                        x0 = normalize(x0);
                    end
                    X = [X, x0];

                end

                Y = [ones(min_trials_take,1); zeros(min_trials_take ,1)];

                if randomize
                    Y = Y(randperm(length(Y)));
                end

                % K-fold cross validation
                indices = crossvalind('Kfold',length(Y),n_folds);

                acc_kfold= [];
                n_kfold_comp = [];

                for k=1:n_folds

                    idx_train = find(indices~=k);
                    idx_test = find(indices==k);

                    X_tr = X(idx_train,:);
                    X_te = X(idx_test,:);
                    Y_tr = Y(idx_train);
                    Y_te = Y(idx_test);

                    if do_pca
                        % normalize X_tr
                        [X_tr_nor, C, S] = normalize(X_tr);
                        % normalize X_te considering the params to normalize X_tr
                        X_te_nor = (X_te - C)./S;

                        % pca only considering training data
                        [coeff, score, latent, tsquared, explained] = pca(X_tr_nor);
                        explained = cumsum(explained);
                        % take the number of components that explain this variance
                        [~, n_comp] = min(abs(explained - n_explained));
                        reduced_explained = coeff(:, 1:n_comp);
                        n_kfold_comp(k) = n_comp; 
                        % reduce training explaineds
                        X_tr = X_tr_nor*reduced_explained;
                        % reduce test explaineds
                        X_te = X_te_nor*reduced_explained;
                    end

                    model_rl = fitcsvm(X_tr,Y_tr,'Standardize', true);
                    [label,score] = predict(model_rl,X_te);
                    accuracY = sum(label==Y_te)/length(idx_test);
                    acc_kfold(k) = accuracY;

                end

                accuracies = [accuracies, acc_kfold];
                n_comp = [n_comp, n_kfold_comp];
            end


            results(n_results).region_name = region_name;
            results(n_results).mean_acc = mean(accuracies);
            results(n_results).std_acc = std(accuracies);
            results(n_results).accuracies = accuracies;
            results(n_results).n_comp = n_comp;
            results(n_results).number_chs = length(category_1);
            results(n_results).number_chs_selected = length(select_ch);
            n_results = n_results + 1;
        end

    end

    save_name = sprintf(['minE_%s_takeE_%s_pca_%s_var_%s_norm_%s_nTimes_%s_kF_%s_random_%s.mat'], ...
        string(min_electrodes), string(take_electrodes), string(do_pca), string(n_explained), string(ifNormalize), string(n_times), string(n_folds), string(randomize))
    save([folder_results save_name], 'results')
end