clc;clear

addpath(genpath('functions_general'));

%% Script to analyze and plot decoding results

% Important! It is necessary to run D01_decoding 2 times: using both times
% EXACTLY the same features, but one with randomize = false, and other with
% randomize = true. It computes whether the non-randomize is significant
% for a p-value of 0.01.

%%
tile = '1';
frequency_band = 'gamma';
option_compare = 1; % 1 if using our method, 2 if using permutationTest

folder2analyze = ['D01_decoding_tile_' tile '/' frequency_band '/'];
folderResults = [folder2analyze 'results/'];
mkdir(folderResults)

% Check all the files on the folder
files = dir(folder2analyze);
files_full = []; % save the full path to the folder
files_names = []; % save the name
files_random = []; % save whether it was random or not
for i = 3:length(files)-1
    name = files(i).name;

    if ~startsWith(name,'results')
        files_full = [files_full; string(name)];
        name_split = split(name, 'random');
        random_ = name_split{2};
        random_ = random_(2:5);
        files_names = [files_names; string(name_split{1})]; 
        files_random = [files_random; string(random_)]; % check whether false or not
    end

end

for i=1:length(files_random)
    
    if files_random(i) == "true" % take both the random and not random versions
        false_folder = intersect(find(files_names == files_names(i)), find(files_random == "fals"));
        
        if ~isempty(false_folder)

            load([string(folder2analyze) + files_full(i)])
            results_chance = results;
            load([string(folder2analyze) + files_full(false_folder)])
            results_true = results;

            results = [];

            % for each brain regions, take true results and chance results and compare
            regions = [];
            accuracies = [];
            sig = [];
            for j=1:length(results_true)

                region = results_true(j).region_name;
                regions = [regions, string(region)];
                results(j).region_name = string(region);

                mean_accuracy = mean(results_true(j).accuracies);
                true_accuracies = results_true(j).accuracies;
                results(j).true_acc = results_true(j).mean_acc;
                results(j).std_acc = std(true_accuracies);
                accuracies(j,:) = true_accuracies;
                chance_accuracies = results_chance(j).accuracies;

                if option_compare == 1
                    p_val = sum(chance_accuracies > mean_accuracy)/length(chance_accuracies);
                else
                    p_val = permutationTest(true_accuracies, chance_accuracies, 2000);
                end

                if p_val<0.01
                    results(j).sig = 1;
                else   
                    results(j).sig = 0;
                end

                if p_val<0.001
                    results(j).sig2 = 1;
                else   
                    results(j).sig2 = 0;
                end
                
                results(j).p_val = p_val;
            end

            % save results
            save([string(folderResults) + files_names(i) + "results.mat"], 'results', 'option_compare')
            
            figure(i)

            ngroups = length(regions);

            % order accuracies
            y_plot = [results.true_acc];
            err_plot = [results.std_acc];
            regions = [results.region_name];
            sig = [results.sig];
            sig2 = [results.sig2];

            [~, idx_sort] = sort(y_plot, 'descend');
            y_plot = y_plot(idx_sort);
            regions = regions(idx_sort);
            sig = sig(idx_sort);
            sig2 = sig2(idx_sort);
            err_plot = err_plot(idx_sort);


            b = bar(y_plot,'FaceColor','flat');
            b(1).FaceColor = [0.5 0.5 0.5];
            ylim([0 1])

            xticks = [1:length(regions)];
            names = regions;
            hold on; 
            title(['accuracies']) 
            ylabel('accuracy');
            xlabel('Brain region');
            e = errorbar((1:ngroups), y_plot, err_plot, '.');
            e.Color = 'black'; 
            e.CapSize = 2.5;

            scatter([1:ngroups], sig-0.05, 'k*')
            scatter([1:ngroups], sig2-0.05, 'r*')
            
            line([0 ngroups+1], [0.5 0.5],'Color','r','linestyle','--','LineWidth',1)

            set(gca,'fontsize', 11,'FontName','Arial','box','off','TickDir','out','xtick',xticks,'xticklabel',names)
            ylim([0.4 1])
            
            saveas(figure(i),[string(folderResults) + files_names(i)],'fig')
            %close(figure(1))
            
        end
    end
end

%%



