clc;clear
% Add libraries
addpath(genpath('functions/functions_general'));
addpath(genpath('functions/chronux_2_12'));
addpath(genpath('functions/figures_behavior'));

%% Create behavior figures test difference in predictors for match vs. mismatch, and also linear model to check whether each predictor increases/decreases with board size

% It plots:
% - Predictor bar plot for match vs. mismatch for each subject
% --> functions/figures_behavior/plot_bar_subjects.mat.
% - Predictor bar plot for match vs. mismatch for each board size - across
% all subjects --> functions/figures_behavior/plot_bar_board_size.mat.

% Linear model:
% - Test whether a predictor increases/decreases with board size, for
% match, mismatch, and both trials --> functions/figures_behavior/lm_boardsize_behavior.mat.

frequency_band = 'gamma';
remove_random = true; % select if remove random matches
subjects = [1:4];

savefolder = ['F01_behavior_figures/' frequency_band '/'];
mkdir(savefolder)


%% FOR ALL SUBJECT

% Create b_data_subject struct, for all subjects
b_data_subjects = struct;
remove1 = {};
for n_subject=subjects
    n_sub = string(n_subject);
    load(fullfile('P00_data_behavior', 'b_data_subject_'+n_sub+'.mat')); % load predictors
    if remove_random
        random_match = find(b_data(2).x == 1);
        image_cat = b_data(7).x;
        remove_distractor = intersect(find(image_cat(1:2:end) == 0), find(image_cat(2:2:end) == 0));
        remove1{n_subject} = union(out_rt', random_match'); % remove random matches and trials with RT outliers
        remove1{n_subject} = union(out_rt', remove_distractor'); % remove also distractor
    else
        remove1{n_subject} = union(out_rt', []);
    end
    for i = 1:length(b_data)
        b_data_subjects(n_subject).(b_data(i).name) = b_data(i).x';
    end
end

%% BAR PLOT FOR EACH SUBJECT

p_value = 0.01;
n_permutations = 10000;
remove_zeros = true;

feature = 'n_since_pair';
tile = 1;
n_fig = 1;
plot_bar_subjects(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_subjects'] ,'jpeg')

feature = 'n_since_last_click';
tile = 1;
n_fig = 2;
plot_bar_subjects(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_subjects'] ,'jpeg')

feature = 'n_since_last_click';
tile = 2;
n_fig = 3;
plot_bar_subjects(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_subjects'] ,'jpeg')

feature = 'n_times_seen';
tile = 1;
n_fig = 4;
plot_bar_subjects(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_subjects'] ,'jpeg')

feature = 'n_times_seen';
tile = 2;
n_fig = 5;
plot_bar_subjects(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_subjects'] ,'jpeg')

%% BAR PLOT FOR EACH BOARD SIZE --> PAPER FIGURE

p_value = 0.01;
n_permutations = 10000;
remove_zeros = true;

feature = 'n_since_pair';
tile = 2;
n_fig = 1;
p2 = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
ylim([0 35])
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_board'] ,'jpeg')

feature = 'n_since_last_click';
tile = 1;
n_fig = 2;
p2 = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
ylim([0 33])
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_board'] ,'jpeg')

feature = 'n_since_last_click';
tile = 2;
n_fig = 3;
p2 = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
ylim([0 33])
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_board'] ,'jpeg')

feature = 'n_times_seen';
tile = 1;
n_fig = 4;
p2 = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
ylim([0 8])
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_board'] ,'jpeg')

feature = 'n_times_seen';
tile = 2;
n_fig = 5;
p2 = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
ylim([0 8])
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_board'] ,'jpeg')

feature = 'reaction_time';
tile = 2; % does not really matter
n_fig = 7;
remove_zeros= false;
p_value = 0.01;
n_permutations = 5000;
[p2] = plot_bar_board_size(n_fig, b_data_subjects, remove1, feature, tile, p_value, n_permutations, remove_zeros)
ylim([0 4])
saveas(figure(n_fig),[savefolder feature '_tile_' num2str(tile) '_board'] ,'jpeg')

%% TEST LINEAR MODEL tile 1

features = ["reaction_time", "n_since_pair", "n_times_seen", "n_since_last_click"];
tile = 1;
use_sqrt = false;
remove_zeros = true;
tile_1_lm_board_size = struct;

for i=1:length(features)
    [p_model_match, tstat_match, p_model_mismatch, tstat_mismatch, p_model, tstat] = lm_boardsize_behavior(b_data_subjects, remove1, features(i), tile, remove_zeros,use_sqrt);
    tile_1_lm_board_size(i).predictor = features(i);
    tile_1_lm_board_size(i).p_value_m = p_model_match;
    tile_1_lm_board_size(i).p_value_i = p_model_mismatch;
    tile_1_lm_board_size(i).p_value_all = p_model;
    tile_1_lm_board_size(i).tstat_m = tstat_match;
    tile_1_lm_board_size(i).tstat_i = tstat_mismatch;
    tile_1_lm_board_size(i).tstat_all = tstat;
end
results = struct2table(tile_1_lm_board_size);
writetable(results, [savefolder 'tile_1_lm_board_size.xlsx'])

%% TEST LINEAR MODEL tile 3

features = ["reaction_time", "n_times_seen", "n_since_last_click"];
tile = 2;
use_sqrt = false;
remove_zeros = true;
tile_2_lm_board_size = struct;

for i=1:length(features)
    [p_model_match, tstat_match, p_model_mismatch, tstat_mismatch, p_model, tstat, board_sizes, matches] = lm_boardsize_behavior(b_data_subjects, remove1, features(i), tile, remove_zeros,use_sqrt);
    tile_2_lm_board_size(i).predictor = features(i);
    tile_2_lm_board_size(i).p_value_m = p_model_match;
    tile_2_lm_board_size(i).p_value_i = p_model_mismatch;
    tile_2_lm_board_size(i).p_value_all = p_model;
    tile_2_lm_board_size(i).tstat_m = tstat_match;
    tile_2_lm_board_size(i).tstat_i = tstat_mismatch;
    tile_2_lm_board_size(i).tstat_all = tstat;
end
results = struct2table(tile_2_lm_board_size);
writetable(results, [savefolder 'tile_2_lm_board_size.xlsx'])




