clc;clear

%% Add libraries
addpath(genpath('functions/functions_general'));
addpath(genpath('functions/chronux_2_12'));
addpath(genpath('functions/figures_electrodes'));

%% Script to plot the figures for each electrode example. 
% Plots:
% - 1: GLM t-statistic of each predictor
% - 2: Power match vs. mismatch, w/wo statistical testing
% - 3: Raster plot match vs. mismatch trials, ordered (or not) by a
% specific predictor
% - 4: Rasper plot for all trials, ordered (or not) by a
% specific predictor. 4a: ordered from smaller to bigger, 4b: ordered from
% bigger to smaller
% - 5: Gamma power for different ranges of predictors' values
% - 6: Scatter plot of the AUC vs. a predictor
% - 7: Plot power for different image categories
% Results are saved in 'F02_electrodes_tile_1'

%%  Load data and prepare

n_subject = 4;
frequency_band = 'gamma';

subject = string(4);
savefolder = sprintf('F02_electrodes_tile_1/%s/subject_%s',frequency_band,subject);
mkdir(savefolder)

load(fullfile('P00_data_behavior','b_data_subject_'+subject+'.mat')); % load behavioral data
load(fullfile('P01_TFD_chronux_tile_1','gamma','P01_subject_'+subject+'.mat')); % load gamma power
load(fullfile('P03_AUC_tile_1',frequency_band,'data_subject_'+subject+'.mat')); % load AUC data
load(fullfile('G01_GLM_tile_1',frequency_band,'subject_'+subject,'glm_subject_'+subject+'.mat')); % load GLM results 

GLM_p = struct2table(GLM_p); GLM_t = struct2table(GLM_t);  GLM_R2 = struct2table(GLM_R2); 
coeff_names = name_x;

t_plot = t_plot_save;
inter_1img_2img = b_data(6).x;
mean_rt = mean(inter_1img_2img);

% discard buffer zone
base_sec = 0.4; 
after_match_sec = 0.5;
[~,plot_start] = min(abs(t_plot-(-base_sec))); 
[~,plot_end] = min(abs(t_plot-(mean(inter_1img_2img)+after_match_sec))); 
t_plot_n = t_plot(plot_start:plot_end);

% remove rials with distractor
image_category = b_data(11).x; 
x1 = image_category(1:2:end);
x2 = image_category(2:2:end);
x_out = union(find(x1 == 0), find(x2 == 0));
out_rt = [out_rt; x_out]; 
image_category = image_category(1:2:end);

%% 1: Plot GLM

% Params
n_ch = 43; % number of the channel to plot glm
p_value1 = 0.001; p_value2 = 0.01; % 1 blue stars if p_value < p_value1, 1 black star if p_value < p_value2 
y_limits = [-3 7];

chs = [GLM_p.n_ch]; % channels 
idx_ch = find(chs == n_ch); 
region_name = GLM_p.region_name; region_name = region_name(5);

tstats = table2array(GLM_t(idx_ch, 4:end));
p_values = table2array(GLM_p(idx_ch, 4:end));
R2 = table2array(GLM_R2(idx_ch, 4));
p_model = table2array(GLM_R2(idx_ch, 5));

tile = 1;
n_fig = 1;
plot_glm_result(n_fig, tstats, p_values, p_model, coeff_names, p_value1, p_value2)
title(sprintf(['%s %s, ch # %s, tile %s'], subject, region_name, num2str(n_ch),num2str(tile)))
xlim([0.5 15.5])
ylim(y_limits)

saveas(figure(n_fig),sprintf(['%sch_%s_glm'], savefolder, num2str(n_ch)),'fig')

%% 2: Plot power Match vs. Mismatch

% Params
n_ch = 43; % # of channel we want to plot
ylimits = [-0.2 6]; % limits plot plower
lines_rt = false; % it plots the RT dashed lines for each group
rt_diff = false; % if perform time equalization
equalization = false; % if perform sample equalization WITHOUT time equalization
test_difference = false; % whether to test or not match and mismatch difference

text_f = 'Z-scored \gamma power'
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
power = P01_power{n_ch};
power = power(plot_start:plot_end, :, :);
match = b_data(1).x; % 1 if a match trial, 0 if mismatch
random_match = b_data(2).x; % to remove random match

tile = 1; % number of the tile
plot_compare_match(power, artifacts, match, random_match, inter_1img_2img, t_plot_n, ylimits, tile, rt_diff, equalization, text_f, test_difference)
title(sprintf('%s ch. %s tile 1',subject, num2str(n_ch)));
saveas(figure(1),sprintf(['%sch_%s_power_match'], savefolder, num2str(n_ch)),'fig')

%% 3: Raster plot Match vs. Mismatch

% Params
n_ch = 43; % channel we want to plot
ylimits = [-0.2 6]; % limits gamma power for colormap
equalization = false; % random equalization of # of match and mismatch trials
rt_diff = false; % equalization by RT
order = false; % if order the trials by the predictor
% ONLY IF ORDER = TRUE -->
plot_predictor_values = [2 10]; % only if order is true, values where to plot the lines
pred_order = b_data(3).x; % 3 if order by n-since-pair, 4 by n-since-last-click, 6 by RT
name_predictor = join(split(b_data(3).name,'_'),'-');
pred_order = pred_order(1:2:end); % take only for first tile, if RT comment this line


power = P01_power{n_ch};
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
power = power(plot_start:plot_end, :, :);
match = b_data(1).x;
random_match = b_data(2).x;
tile = 1;

% removing zeros
remove1 = find(pred_order == 0);
artifacts = union(remove1, artifacts);

plot_raster_match(power, artifacts, match, random_match, inter_1img_2img, t_plot_n, ylimits, tile, equalization,rt_diff,order,pred_order,plot_predictor_values, name_predictor)
if order
    saveas(figure(1),sprintf(['%sch_%s_raster_match_%s'], savefolder, num2str(n_ch), name_predictor{1}),'fig')
    saveas(figure(2),sprintf(['%sch_%s_raster_mismatch_%s'], savefolder, num2str(n_ch), name_predictor{1}),'fig')
else
    saveas(figure(1),sprintf(['%sch_%s_raster_match'], savefolder, num2str(n_ch)),'fig')
    saveas(figure(2),sprintf(['%sch_%s_raster_mismatch'], savefolder, num2str(n_ch)),'fig')
end

%% 4a: Raster plot all trials: from smaller to larger predictor

% Params
n_ch = 43; % channel we want to plot
ylimits = [-0.2 6]; % limits gamma power for colormap
order = true; % if order the trials by the predictor
% ONLY IF ORDER = TRUE -->
plot_predictor_values = [1 2]; % only if order is true, values where to plot the lines
pred_order = b_data(4).x; % 3 if order by n-since-pair, 4 by n-since-last-click, 6 by RT
name_predictor = join(split(b_data(4).name,'_'),'-');
pred_order = pred_order(1:2:end); % take only for first tile, if RT comment this line

power = P01_power{n_ch};
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
power = power(plot_start:plot_end, :, :);
random_match = b_data(2).x;
tile = 1;

% removing zeros
%remove1 = find(pred_order == 0);
%artifacts = union(remove1, artifacts);

plot_raster(power, artifacts, random_match, inter_1img_2img, t_plot_n, ylimits, tile, order, pred_order, plot_predictor_values, name_predictor)
saveas(figure(1),sprintf(['%sch_%s_raster_%s'], savefolder, num2str(n_ch), name_predictor{1}),'fig')


%% 4b: Raster plot all trials: from larger to smaller predictor

% Params
n_ch = 43; % channel we want to plot
ylimits = [-0.2 6]; % limits gamma power for colormap
order = true; % if order the trials by the predictor
% ONLY IF ORDER = TRUE -->
plot_predictor_values = [999 2]; % only if order is true, values where to plot the lines
pred_order = b_data(4).x; % 3 if order by n-since-pair, 4 by n-since-last-click, 6 by RT
name_predictor = join(split(b_data(4).name,'_'),'-');
pred_order = pred_order(1:2:end); % take only for first tile, if RT comment this line

power = P01_power{n_ch};
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
power = power(plot_start:plot_end, :, :);
random_match = b_data(2).x;
tile = 1;

pred_order(pred_order == 0) = 1000;
% removing zeros
%remove1 = find(pred_order == 0);
%artifacts = union(remove1, artifacts);

plot_raster_reverse(power, artifacts, random_match, inter_1img_2img, t_plot_n, ylimits, tile, order, pred_order, plot_predictor_values, name_predictor)
saveas(figure(1),sprintf(['%sch_%s_raster_%s'], savefolder, num2str(n_ch), name_predictor{1}),'fig')

%% 5: Plot compare gamma power for different predictor values

% Params
n_ch = 43;
n_predictor = 3; % 3 if order by n-since-pair, 4 by n-since-last-click, 6 by RT
select_match_mismatch = 3; % if 1 plot for match, if 2 for mismatch, 3 rest for all
ylimits = [-0.2 6]; % limits
thrs = [1]; % thresholds, e.g. [10,20] will take x<10, 10<=x<20, 20<=x, it can be as long as you want
min_rt = 0; % min RT to include a trial 
max_rt = 10000; % max RT to include a trial 
lines_rt = false; % if include RT for each separate line power
plot_zeros = true; % if include trials where the predictor equals 0

tile = 1;
power = P01_power{n_ch}; power = power(plot_start:plot_end, :, :);
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
remove_rt = union(find(inter_1img_2img>max_rt),find(inter_1img_2img<min_rt));
artifacts = unique([artifacts, remove_rt']); % remove trials with out of limits RT
predictor =b_data(n_predictor).x; 
predictor = predictor(1:2:end); % IF PREDICTOR IS RT COMMENT
name_predictor = b_data(n_predictor).name;
match = b_data(1).x;
random_match = b_data(2).x;
if select_match_mismatch == 1
    idx_out = union(find(match == 0), find(random_match == 1));
    artifacts = unique([artifacts, idx_out']); % remove mismatch and random trials
    name_predictor = [name_predictor '*match'];
elseif select_match_mismatch == 2
    idx_out = find(match == 1);
    artifacts = unique([artifacts, idx_out']); % remove match trials
    name_predictor = [name_predictor '*mismatch'];
end
legend_text = join(split(name_predictor,'_'), '-');
name_predictor = join(split(name_predictor,'*'), '_');

plot_compare_predictor_power(predictor, power, artifacts, thrs, tile, t_plot_n, inter_1img_2img, legend_text, ylimits, lines_rt, plot_zeros)
title(sprintf(['%s ch. %s tile rt'], subject, num2str(n_ch)))
saveas(figure(n_fig),sprintf(['%sch_%s_power_%s'], savefolder, num2str(n_ch), name_predictor{1}),'fig')

%% 6: Scatter plot: AUC vs. predictor

% Params
n_ch = 43;
n_predictor = 3; % 3 if order by n-since-pair, 4 by n-since-last-click, 6 by RT
select_match_mismatch = 2; % if 1 plot for match, if 2 for mismatch, 3 rest for all
remove_zeros = true; % whether to remove or not the 0s

chs = [X_data.n_ch]; 
idx_ch = find(chs == n_ch);
auc_data = X_data(idx_ch).auc;
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
predictor = b_data(n_predictor).x; 
predictor = predictor(1:2:end); % select only for 1st tile, IF PREDICTOR IS RT COMMENT
name_predictor = b_data(n_predictor).name;
match = b_data(1).x;
random_match = b_data(2).x;
if select_match_mismatch == 1
    idx_out = union(find(match == 0), find(random_match == 1));
    artifacts = union(artifacts, idx_out);
    name_predictor = [name_predictor '*match'];
elseif select_match_mismatch == 2
    idx_out = find(match == 1);
    artifacts = union(artifacts, idx_out);
    name_predictor = [name_predictor '*mismatch'];
end
x_name = join(split(name_predictor,'_'), '-');

plot_compare_auc(predictor, auc_data, artifacts, x_name, remove_zeros)
title(sprintf(['%s ch. %s tile 1'], subject, num2str(n_ch)))
ylim([min(auc_data) max(auc_data)])
name_predictor = join(split(name_predictor,'*'), '_');
saveas(figure(n_fig),sprintf(['%sch_%s_scatter_%s'], savefolder, num2str(n_ch), name_predictor{1}),'fig')

%% 7: Plot gamma power for different image categories

% Params
n_ch = 43;
include_distractor = false; % whether to include or not distractor image (we have consider distractors as artifacts at the beginning, so account for that_
ylimits = [-1 4]; % y-limits of the plot

power = P01_power{n_ch};
artifacts = P01_art{n_ch};
artifacts = unique([artifacts, out_rt']);
power = power(plot_start:plot_end, :, :);
power(:, :, artifacts) = [];
img_cat = image_category; img_cat(artifacts) = [];

plot_image_category(power, img_cat, tile, mean_rt, t_plot_n, ylimits, include_distractor)
saveas(figure(n_fig),sprintf(['%sch_%s_image_category'], savefolder, num2str(n_ch)),'fig')
