clc;clear

%% Compute ONE true GLM for individual electrodes

% This scripts compute ONE single GLM for each electrode (NO subsampling
% is used). It loops over the AUC data (created w/ P03_AUC_tile1/2.mat) and
% predictors (from P00_behavioral_data.mat) previously computed.
% For each subject, it create a subfolder in the save_figs folder with the
% name of the subject and the model used, where it saves the glm results (GLM_p: p-values, GLM_t: tstats, GLM_b: gammas, GLM_R2: r-squared)
% for all the electrodes for each subject.
% It also plots the gamma values for each electrode

%% SELECT TILE -->

tile = 1;

%% Params

subjects = [1:4];
frequency_band = 'gamma';

savefolder = sprintf(['G01_GLM_tile_%s/%s/'],num2str(tile),frequency_band); % where to save the figures
mkdir(savefolder)

folder = sprintf(['P03_AUC_tile_%s/%s/'],num2str(tile),frequency_band);

for n_subject = subjects

    % Load behavioral data
    subject = n_subject;
    n_sub = string(n_subject);
    load(fullfile(folder,'data_subject_'+n_sub+'.mat')); % load AUC data
    load(fullfile('P00_data_behavior', 'b_data_subject_'+n_sub+'.mat')); % load b_data
    
    saveresults = fullfile(savefolder,'subject_'+n_sub+'/');
    mkdir(saveresults)
    
    % To save predictors for each tile
    x_1tile = [];
    x_2tile = [];

    % Name of the predictors
    name_x1 = {};
    name_x2 = {};

    categories_img = {'distractor',  'indoor', 'animal', 'food', 'person', 'vehicle'};
    max_tiles = length(b_data(4).x); % total number of tiles clicked
    
    j1 = 1; j2 = 1;
    for i=1:length(b_data)
        x = b_data(i).x;
        if convertCharsToStrings(b_data(i).name) == "image_category"
            x1 = x(1:2:end); % for tile 1 all trials
            x2 = x(2:2:end); % for tile 2 all trials
            x_1tile = [x_1tile, x1];
            x_2tile = [x_2tile, x2];
            name_x1{j1} = ['image-']; j1 = j1+1; 
            name_x2{j2} = ['image-']; j2 = j2+1; 
            out_distractor = union(find(x1 == 0), find(x2 == 0)); % to later discard distractor trials
        elseif convertCharsToStrings(b_data(i).name) == "random_match" % we do not include it, but we need to discard random trials
            out_random = find(x == 1);
        elseif convertCharsToStrings(b_data(i).name) == "board_size" && n_subject == 14 % subject 14 does not have board size as predictor
            n_ic = j1;
        elseif convertCharsToStrings(b_data(i).name) == "n_since_pair"
            x_1t = x(1:2:end, :);
            % include interaction term n_since_pair*match
            match = b_data(1).x;
            x_1tile = [x_1tile, x_1t.*match];
            name_x1{j1} = ['n-since-pair*match']; j1 = j1+1; 
        elseif convertCharsToStrings(b_data(i).name) == "unseen_unmatch" % we do not include it
            n_sub
        elseif convertCharsToStrings(b_data(i).name) == "n_since_last_click";
            % create from n_since_last_click, the first_click bariable
            x_1t = x(1:2:end, :);
            x_never_click_1 = zeros(size(x_1t));
            x_never_click_1(x_1t == 0) = 1;
            x_2t = x(2:2:end, :);
            x_never_click_2 = zeros(size(x_2t));
            x_never_click_2(x_2t == 0) = 1;
            x_1tile = [x_1tile, x_1t, x_never_click_1];            
            x_2tile = [x_2tile, x_2t, x_never_click_2];
            name_x1{j1} = ['n-since-last-click']; j1 = j1+1;
            name_x2{j2} = ['n-since-last-click']; j2 = j2+1;
            name_x1{j1} = ['first-click']; j1 = j1+1;
            name_x2{j2} = ['first-click']; j2 = j2+1;
        else
            % for the rest of the predictors
            if size(x, 1) == max_tiles % for variables dependent on the tile #
                x_1tile = [x_1tile, x(1:2:end, :)]; % only consider for the 1st tile
                x_2tile = [x_2tile, x(2:2:end, :)]; % only consider for the 2nd tile
            else % for variables only dependent on the trial
                x_1tile = [x_1tile, x]; 
                x_2tile = [x_2tile, x]; 
            end
            name = join(split(b_data(i).name, '_'), '-');
            name_x1{j1} = name{1}; name_x2{j2} = name{1};
            j1 = j1 + 1;j2 = j2 + 1;
        end  
    end
    
    % Add next-match predictor
    next_match = b_data(1).x;
    next_match = [next_match(2:end); 0];
    x_1tile(:, j1) = next_match;
    name_x1{j1} = 'next-match';
    x_2tile(:, j2) = next_match;
    name_x2{j2} = 'next-match';
    
    if tile == 1
        n_ic = j1;
    else
        n_ic = j2;
    end

    
    % reorder variables, so next-match is not at the end
    order_1 = [1:size(x_1tile, 2)];
    order_1(7:end) = order_1(6:end-1); order_1(6) = size(x_1tile, 2);
    order_2 = [1:size(x_2tile, 2)];
    order_2(6:end) = order_2(5:end-1); order_2(5) = size(x_2tile, 2);
    x_1tile = x_1tile(:,order_1);
    x_2tile = x_2tile(:,order_2);
    name_x1_new = {};
    for i_name = 1:length(name_x1);
        name_x1_new{i_name} = name_x1{order_1(i_name)};
    end
    name_x1 = name_x1_new;
    name_x2_new = {};
    for i_name = 1:length(name_x2);
        name_x2_new{i_name} = name_x2{order_2(i_name)};
    end
    name_x2 = name_x2_new;


    n_electrodes = length(X_data);

    GLM_p = struct;
    GLM_b = struct;
    GLM_t = struct;
    GLM_R2 = struct;

    % Create predictors_new: depending on the tile we are selecting
    if tile == 1
        xs_tile = x_1tile;
        name_x_ = name_x1;
    else
        xs_tile = x_2tile;
        name_x_ = name_x2;
    end

    for i_ch=1:n_electrodes

        %save region name, number of the channel, and subject
        region_name = X_data(i_ch).region_name;
        n_ch = X_data(i_ch).n_ch;
        
        GLM_p(i_ch).region_name = region_name; GLM_b(i_ch).region_name =region_name;
        GLM_t(i_ch).region_name = region_name; GLM_R2(i_ch).region_name = region_name;
        
        GLM_p(i_ch).n_ch = n_ch; GLM_b(i_ch).n_ch = n_ch;
        GLM_t(i_ch).n_ch = n_ch; GLM_R2(i_ch).n_ch = n_ch;
        
        GLM_p(i_ch).subject = subject; GLM_b(i_ch).subject = subject;
        GLM_t(i_ch).subject = subject; GLM_R2(i_ch).subject = subject;
        
        remove1 = X_data(i_ch).artifacts; % remove artifacts electrodes signal
        remove1 = unique([remove1, out_rt']); % remove rt artifacts
        remove1 = unique([remove1, out_random']); % remove random trials
        remove1 = unique([remove1, out_distractor']); % remove distractor trials

        xs = xs_tile;
        xs(remove1, :) = [];

        % we use the AUC
        feat = 'auc';

        %take data and remove artifacts
        Y = X_data(i_ch).(feat);
        Y(remove1) = [];

        name_feats = name_x_;
        name_feats{length(name_feats)+1} = feat;

        %compute glm and save results
        mdl = fitglm(xs, Y, 'VarNames', name_feats, 'CategoricalVars', [1,n_ic]);
        coeff_names = mdl.CoefficientNames;
        p_values = mdl.Coefficients.pValue;
        gammas = mdl.Coefficients.Estimate;
        tstats = mdl.Coefficients.tStat;
        R = mdl.Rsquared.Ordinary;

        categories_img = {'indoor', 'animal', 'food', 'person','vehicle'};
        name_x = {};

        for n=2:length(coeff_names)
            name = join(split(coeff_names{n}, '-'), '_');
            name = join(split(name, '*'), '_');
            name = name{1};
            GLM_p(i_ch).([name '_' feat]) = p_values(n);
            GLM_b(i_ch).([name '_' feat]) = gammas(n);
            GLM_t(i_ch).([name '_' feat]) = tstats(n);
            nx = coeff_names{n};
            % re-name
            if convertCharsToStrings(nx(1:6)) == "image-"
                number = split(nx, '_');
                number = str2num(number{2});
                name_x{n-1} = [categories_img{number}];
            elseif convertCharsToStrings(nx) == "match_1"
                name_x{n-1} = ['match'];
            else
                name_x{n-1} = [nx];
            end
        end

        GLM_R2(i_ch).(['r2_' feat]) = R;
        p_model = coefTest(mdl);
        GLM_R2(i_ch).(['p_' feat]) = p_model;

        % plot GLM results
        if p_model <= 1
            figure(1)
            set(gcf,'Position',[500 500 600 400])

            x  = [1:length(coeff_names)-1];
            tstats = tstats(2:end);
            bar(x, tstats, 'FaceColor', [0.5 0.5 0.5]) % plot the tstats
            hold on
            
            % One red stars if p_value < 0.01, one black star if p_value < 0.05
            p_value1 = 0.001; p_value2 = 0.01;
            p_values = p_values(2:end);
            ind_1 = find(p_values <= p_value1);
            text(ind_1-0.27, tstats(ind_1) + 0.5*sign(tstats(ind_1)) - 1*(tstats(ind_1) < 0), repmat('*',length(ind_1), 1), 'FontSize', 35, 'Color', '#A2142F')
            ind_2 = intersect(find(p_values > p_value1),  find(p_values < p_value2));
            text(ind_2-0.27, tstats(ind_2) + 0.5*sign(tstats(ind_2)) - 1*(tstats(ind_2) < 0), repmat('*',length(ind_2), 1), 'FontSize', 35)
            ylim([-11 11])
            ylabel('b/SE')
            title(sprintf(['%s %s, ch # %s, tile %s, feat %s'], n_sub, region_name, num2str(n_ch), num2str(tile), feat))

            xticks(x)
            xticklabels(name_x);
            set(gca,'fontsize', 18,'TickDir','out','FontName','Arial','box','off')

            leg = legend(sprintf(['R2 %s, p=%s'], num2str(R), num2str(p_model)),'p<=0.01','p<=0.05','FontName','Arial');
            leg.FontSize = 20;

            ax = gca;
            ax.FontSize = 18; 
            saveas(figure(1), sprintf(['%sn_ch_%s_%s'],saveresults,num2str(n_ch),region_name),'jpeg')
            close(figure(1))
        end
    end
    
    % if subject 14 --> Board size not a predictor, account for this
    if n_subject == 14
        GLM_p_new = struct;
        GLM_b_new = struct;
        GLM_t_new = struct;
        names = fieldnames(GLM_p);
        n = 1;
        for i = 1:length(names) + 1;
            if i ~= 10
                for j=1:length(GLM_p)
                    GLM_p_new(j).(names{n}) = GLM_p(j).(names{n});
                    GLM_b_new(j).(names{n}) = GLM_b(j).(names{n});
                    GLM_t_new(j).(names{n}) = GLM_t(j).(names{n});
                end
                n = n+1;
            else
                for j=1:length(GLM_p)
                    GLM_p_new(j).('board_size_auc') = 1;
                    GLM_b_new(j).('board_size_auc') = 0;
                    GLM_t_new(j).('board_size_auc') = 0;
                end
            end
        end
        GLM_p = GLM_p_new;
        GLM_b = GLM_b_new;
        GLM_t = GLM_t_new;
    end

    save(fullfile(saveresults,'glm_subject_'+n_sub+'.mat'), 'GLM_p', 'GLM_b', 'GLM_t', 'GLM_R2', 'coeff_names', 'name_x', 'remove1')
end



