clc;clear

%% Create table for predictors

% Creates a table with the results of all channels selective for the indicated predictor and selected tile.

% use common predictor names, except for using match_1 --> match, image__2
% --> animal, image__3 --> food, image__4 --> person, image__5--> vehicle
predictors = {'match_1'}; % select one or more predictors
%predictors = {'image__2', 'image__3', 'image__4', 'image__5'}; % select one or more predictors
tile = 1;
p_value = 0.01;
subjects = [1:4]; % indicate subjects
frequency_band = 'gamma';

%% Analyze which electrodes are significant

savefolder = ['G04_table_predictors/' frequency_band '/'];
mkdir(savefolder)
name_predictors = [];
for n=1:length(predictors)
    name_predictors = [name_predictors '_' predictors{n}];
end
savefile = sprintf(['%s%s_tile_%s.xlsx'],savefolder,name_predictors(2:end),num2str(tile));

% tile 1
folder = ['G01_GLM_tile_1/' frequency_band '/'];
load(fullfile(folder,'subject_'+string(subjects(1)),'glm_subject_'+string(subjects(1))+'.mat'));
GLM_p_1 = GLM_p;
GLM_t_1 = GLM_t;
GLM_R2_1 = GLM_R2;
for n_subject = subjects(2:end)
    n_sub = string(n_subject);
    load(fullfile(folder,'subject_'+n_sub,'glm_subject_'+n_sub+'.mat'));
    GLM_p_1 = [GLM_p_1, GLM_p];
    GLM_t_1 = [GLM_t_1, GLM_t];
    GLM_R2_1 = [GLM_R2_1, GLM_R2];
    clear GLM_p GLM_b GLM_t GLM_R2
end

%tile 2
folder = ['G01_GLM_tile_2/' frequency_band '/'];
load(fullfile(folder,'subject_'+string(subjects(1)),'glm_subject_'+string(subjects(1))+'.mat'));
GLM_p_2 = GLM_p;
GLM_t_2 = GLM_t;
GLM_R2_2 = GLM_R2;
for n_subject = subjects(2:end)
    n_sub = string(n_subject);
    load(fullfile(folder,'subject_'+n_sub,'glm_subject_'+n_sub+'.mat'));
    GLM_p_2 = [GLM_p_2, GLM_p];
    GLM_t_2 = [GLM_t_2, GLM_t];
    GLM_R2_2 = [GLM_R2_2, GLM_R2];
    clear GLM_p GLM_b GLM_t GLM_R2
end

%% predictor

if tile == 1
    p_reg = GLM_p_1;
    R2_reg = GLM_R2_1;
    R2 = [R2_reg.p_auc];
    ch_in = [];
    for predictor=1:length(predictors)
        p = [p_reg.([predictors{predictor} '_auc'])];
        ch_in_x = intersect(find(p <= 0.01), find(R2 <= 0.01));
        ch_in = union(ch_in,ch_in_x);
    end
    p_predictor_1 = p_reg(ch_in);
    R2_predictor_1 = R2_reg(ch_in);

    p_reg = GLM_p_2;
    R2_reg = GLM_R2_2;
    p_predictor_2 = p_reg(ch_in);
    R2_predictor_2 = R2_reg(ch_in);
    
    % order by regions
    regions = [p_predictor_1.region_name];
    [~, idx] = sort(regions);
    p_predictor_1 = p_predictor_1(idx);
    p_predictor_2 = p_predictor_2(idx);
    R2_predictor_2 = R2_predictor_2(idx);
    p_model_2 = [R2_predictor_2.p_auc];
    not_good_model_2 = find(p_model_2 > 0.01);
    not_good_model_1 = [];
else
    p_reg = GLM_p_2;
    R2_reg = GLM_R2_2;
    R2 = [R2_reg.p_auc];
    ch_in = [];
    for predictor=1:length(predictors)
        p = [p_reg.([predictors{predictor} '_auc'])];
        ch_in_x = intersect(find(p <= 0.01), find(R2 <= 0.01));
        ch_in = union(ch_in,ch_in_x);
    end
    p_predictor_2 = p_reg(ch_in);
    R2_predictor_2 = R2_reg(ch_in);
    
    p_reg = GLM_p_1;
    R2_reg = GLM_R2_1;
    p_predictor_1 = p_reg(ch_in);
    R2_predictor_1 = R2_reg(ch_in);
    
    % order by regions
    regions = [p_predictor_2.region_name];
    [~, idx] = sort(regions);
    p_predictor_1 = p_predictor_1(idx);
    p_predictor_2 = p_predictor_2(idx);
    R2_predictor_1 = R2_predictor_1(idx);
    p_model_1 = [R2_predictor_1.p_auc];
    not_good_model_1 = find(p_model_1 > 0.01);
    not_good_model_2 = [];
end

%%

T1  = struct2table(p_predictor_1);
T2  = struct2table(p_predictor_2);

most1 = [];
for i=1:size(T1, 1)
    all_preds = T1{i, 4:end};
    [~, m] = min(all_preds);
    most1 = [most1, m];
end

most2 = [];
for i=1:size(T2, 1)
    all_preds = T2{i, 4:end};
    [~, m] = min(all_preds);
    most2 = [most2, m];
end


for i=4:length(T1.Properties.VariableNames)
    column = T1.(i);
    n_ch_most = find(most1 == (i-3));
    new_column = [];
    for j=1:length(column)
        v = column(j);
        value = "";
        if v <= 0.001
            value = "***";
        elseif v <= 0.01
            value = "**";
%         elseif v <= 0.05
%             value = "*";
        end
        if ~isempty(find(n_ch_most == j))
            value = sprintf(['%s %s'], value, "X");
        end
        if ~isempty(find(not_good_model_1 == j))
            value = '-'
        end
        value
        new_column = [new_column, string(value)];
    end
    T1.(i)=convertStringsToChars(new_column');
end
for i=4:length(T2.Properties.VariableNames)
    column = T2.(i);
    n_ch_most = find(most2 == (i-3));
    new_column = [];
    for j=1:length(column)
        v = column(j);
        value = "";
        if v <= 0.001
            value = "***";
        elseif v <= 0.01
            value = "**";
%         elseif v <= 0.05
%             value = "*";
        end
        if ~isempty(find(n_ch_most == j))
            value = sprintf(['%s %s'], value, "X");
        end
        if ~isempty(find(not_good_model_2 == j))
            value = '-'
        end
        new_column = [new_column, string(value)];
    end
    T2.(i)=convertStringsToChars(new_column');
end


%%
writetable(T1,savefile,'Sheet',1,'Range','A1')
writetable(T2,savefile,'Sheet',2,'Range','A1')

