clc;clear

%% Statistical testing to check whether a region has more significant channels than expected by chance

% To determine if any brain region contained significantly more electrodes 
% significant for one predictor than expected by chance, we randomly sampled
% the same number (n) of electrodes as those that were significant for this 
% predictor in the GLM, from the total electrode population (separate for gray 
% and white matters) for 10,000 iterations. Taking the match predictor for gray 
% matter electrodes as an example, from the total 676 gray matter locations, 
% we randomly sampled 32 locations (the number of match-significant gray matter electrodes) 
% for 10,000 times, and calculated the p-value of any location, say insula, 
% as the number of times when n (insula, real) was less than n (insula, sampled). 
% If p$<$0.01, we considered that brain region had significantly more electrodes than purely expected by chance.


subjects = [1:4];
tile = 1;
frequency_band = 'gamma';

%% Load data

savefolder = ['G05_regions_statistics/' frequency_band '/'];
mkdir(savefolder)
save_name = sprintf(['%stile_%s.xlsx'],savefolder,num2str(tile));

folder = sprintf(['G01_GLM_tile_%s/%s/'],num2str(tile),frequency_band);
load(fullfile(folder,'subject_'+string(subjects(1)),'glm_subject_'+string(subjects(1))+'.mat'));
GLM_p_all = GLM_p;
GLM_t_all = GLM_t;
GLM_R2_all = GLM_R2;
for n_subject = subjects(2:end)
    n_sub = string(n_subject);
    load(fullfile(folder,'subject_'+n_sub,'glm_subject_'+n_sub+'.mat'));
    GLM_p_all = [GLM_p_all, GLM_p];
    GLM_t_all = [GLM_t_all, GLM_t];
    GLM_R2_all = [GLM_R2_all, GLM_R2];
    clear GLM_p GLM_b GLM_t GLM_R2
end


% take regions and correct name of regions
regions = [GLM_p_all.region_name];
unique_regions = unique(regions);

%% correct regions name

% if tile == 1
%     unique_regions = unique(regions);
%     n = char(unique_regions(31));
%     for i_reg = 1:length(regions);
%         r = split(regions(i_reg), n(end));
%         regions(i_reg) = r{1};
%     end
%     unique_regions = unique(regions);
% end


%% Statistical test

% take predictor we want to check and channels significant for this
% predictor (can also be commented and load this)
results = [];
for n_pred=2:length(coeff_names)
    predictor = coeff_names{n_pred};
    predictor = join(split(predictor,'-'),'_');
    predictor = join(split(predictor,'*'),'_');
    predictor = predictor{1};
    results(n_pred-1).predictor = predictor;
    ch_predictor_significant = find([GLM_p_all.([predictor '_auc'])] < 0.01);
    ch_model_significant = find([GLM_R2_all.p_auc] < 0.01);
    ch_significant = intersect(ch_predictor_significant, ch_model_significant);

    %% PERFORM TEST

    % regions we need to check if significant nb of electrodes
    regions_ch_significant = regions(ch_significant);
    regions2check = unique(regions_ch_significant);
    % count # of significant electrodes in each regions
    N_regions = hist(categorical(regions_ch_significant), categorical(regions2check));

    % do randsampling over all electrodes
    iterations = 10000;
    n_total_regions = length(regions);
    n_take = length(ch_significant);
    counts = [];
    for i=1:iterations
        ch2take = randsample(n_total_regions,n_take);
        counts(i,:) =  hist(categorical(regions(ch2take)), categorical(regions2check));
    end

    %% create distributions and check p_values
    p_values = [];
    for i_reg=1:length(regions2check)
        count = counts(:,i_reg);
        p_values(i_reg) = sum(count >= N_regions(i_reg))/iterations;
    end

    significant_regions = regions2check(p_values < 0.01);
    results(n_pred-1).regions = significant_regions;
    
end

results = struct2table(results);
writetable(results, save_name)