clc;clear
addpath(genpath('functions/chronux_2_12'));
addpath(genpath('functions/functions_general'));

%% SCRIPT TO COMPUTE TIME-FREQUENCY DECOMPOSITION (TFD), ALINGMENT TO 1st TILE

% This script computes the TFD from the raw signal, for each channel.
% - The code has to be run subject by subject
% - Select the "good channels" for each subject by copy-pasting the info
% for each channel in info_channels_gray_matter.m or info_channels_white_matter.m 
% - Indicate the frequency band that you want to compute below. Param:
% frequency_band.
% - The script saves the power ('P01_power'), the artifacts ('P01_art'), and the corresponding time
% vector ('t_plot_save')

% frequency band we want to compute
frequency_band = "gamma";
% where to save results
save_folder = sprintf(['P01_TFD_chronux_tile_1/%s/'], frequency_band);

%% To modify for each subject !!

n_subject = 3; % INDICATE SUBJECT

% For gray-matter copy-paste info from info_channels_gray_matter.m 
% For white-matter copy-paste infrom from info_channels_white_matter.m
bad_channel = [1 3:7 9 12:17 19:21 23:25 28 29 31 33:39 41:46 48 49 52:56 58 59 63:66 68:70 72:76 79:85 87:94 97:99 102:109]; 
total_channel = 114;  
good_channel = sort(setdiff(1:total_channel,bad_channel)); 
sr = 512; 
rt_diff = 1;

mkdir(save_folder)

%% Load data: path to data

n_sub = string(n_subject);
load(fullfile('data_psychophysics','subject_'+n_sub,'b_data.mat'));
load(fullfile('data_iEEG','subject_'+n_sub,'nf_subject_'+n_sub+'.mat')); % voltage
load(fullfile('data_iEEG','subject_'+n_sub,'trigger_info.mat'));
load(fullfile('data_localization','hdr_subject_'+n_sub+'.mat')); % electrodes' localization

%% Set parameters for TFD

raw_voltage = nf_raw; 

buffer_zone = round(sr*0.15); % 200 msec
buffer_zone_sec = 0.15; 
base_length = round(sr*0.4); % 400 msec
base_sec = 0.4; 
after_match = round(sr*1); % 1 sec
after_match_sec = 1; 

params.Fs = sr;
params.trialave = 0; 

if frequency_band == "gamma"
    params.fpass = [30 150]; % taper method not appropriate for <30 Hz 
    params.tapers = [5 7]; 
    movingwin = [0.2 0.01];
elseif frequency_band == "gamma"
    params.fpass = [14 30]; % taper method not appropriate for <30 Hz 
    params.tapers = [3 5];  
    movingwin = [0.3 0.01];
elseif frequency_band == "alpha"
    params.fpass = [8 14]; % taper method not appropriate for <30 Hz 
    params.tapers = [2 3]; 
    movingwin = [0.4 0.01]; 
else
    sprintf("WRONG FREQUENCY BAND NAME")
end

%% Compute TFG

for i_ch = 1:length(good_channel)
    
    i_ch
    i_channel = good_channel(i_ch);
    current = 1;
    S_trial_norm = [];
    
    for i = 1:height(trigger_info)
        if strcmp(trigger_info.label{i},'twoFlipped') 
            
            start = trigger_info.timestamp(i)-round(inter_1img_reset(current)*sr)-base_length-buffer_zone; 
            ending = start+buffer_zone+base_length+round(mean(inter_1img_2img)*sr)+after_match+buffer_zone;
            
            tent = raw_voltage(i_channel,start:ending); 
            rawData(current,:) = tent((buffer_zone+1):(length(tent)-buffer_zone)); % for art rejection
            [S_trial,t,f] = mtspecgramc(tent',movingwin,params);
            
            base_start = trigger_info.timestamp(i)-round(inter_1img_reset(current)*sr)-base_length-buffer_zone; 
            base_end = trigger_info.timestamp(i)-round(inter_1img_reset(current)*sr)+buffer_zone; 
            tent_base = raw_voltage(i_channel,base_start:base_end); 
            [S_base, t_base, f_base] = mtspecgramc(tent_base',movingwin,params);
            [~, buff_start] = min(abs(t_base-buffer_zone_sec));
            buff_end = length(t_base)-buff_start;
            S_base = S_base(buff_start:buff_end,:);
            mean_base = mean(S_base);
            std_base = std(S_base);

            % z-score normalization
            for j = 1:length(f)
                S_trial_norm(:,j,current) = (S_trial(:,j)-mean_base(j))/std_base(j);
            end
            current = current+1;           
        end
    end
    
    % Save power
    P01_power{i_channel} = S_trial_norm; 
    
    % Artifacts
    amps = range(rawData');
    remove1 = find(amps>=(mean(amps)+std(amps)*5)); 
    P01_art{i_channel} = remove1; 
    
    [~,imgOnset_in_t] = min(abs(t-buffer_zone_sec-base_sec)); 
    t_plot = t-t(imgOnset_in_t);
    t_plot_save = t_plot;
    t_plot = t_plot_save;
    
    % Save loc
    data_loc{i_channel} = hdr(i_channel).locus;
   
end

% saves power, artifacts, and time vector
save(fullfile(save_folder,'P01_subject_'+n_sub+'.mat'),'P01_power','P01_art','t_plot_save','data_loc','f','-v7.3');

