clc;clear

addpath(genpath('functions/customcolormap'));

%% Compute VIF and pair-wise correlations across predictors used in the GLM

% It first organizes the predictor and divides between 1st and 2nd tile.
% It computes the VIF and pair-wise correlation for each subjects, results
% are savesd in 'P04_VIF_correlation'.
% Finally, it computes the average VIF and pair-wise correlation across all subjects (results
% from paper).


%% Params

subjects = [1:4]; % select the subjects for which we want to compute results

savefolder = 'P04_VIF_correlation/'; % where to save the figures
mkdir(savefolder)

%%
VIF_tile1 = struct;
VIF_tile2 = struct;

x_1tile_all = {};
x_2tile_all = {};

plot_14 = false;

for n_subject = subjects
    
    % Load behavioral data
    n_sub = string(n_subject);
    load(fullfile('P00_data_behavior','b_data_subject_'+n_sub+'.mat')); % load b_data
    
    % To save VIF for each subjet
    VIF_tile1(n_subject).subject = n_subject;
    VIF_tile2(n_subject).subject = n_subject;
    
    % To save predictors for each tile
    x_1tile = [];
    x_2tile = [];

    % Name of the predictors
    name_x1 = {};
    name_x2 = {};

    categories_img = {'distractor',  'indoor', 'animal', 'food', 'person', 'vehicle'};
    max_tiles = length(b_data(4).x); % total number of tiles clicked
    
    if n_subject == 14
        idx_14 = n_subject;
        plot_14 = true;
    end
    
    j1 = 1; j2 = 1;
    for i=1:length(b_data)
        x = b_data(i).x;
        if convertCharsToStrings(b_data(i).name) == "image_category"
            categories_in = [2, 3, 4, 5]; % we discard indoor category to avoid falling into the "dummy" trap
            for n_cat = categories_in
                x_cat = zeros(size(x));
                x_cat(find(x == n_cat)) = 1;
                x_1tile = [x_1tile, x_cat(1:2:end)];
                x_2tile = [x_2tile, x_cat(2:2:end)];
                name_x1{j1} = [categories_img{n_cat+1}];
                name_x2{j2} = [categories_img{n_cat+1}];
                j1 = j1+1; j2 = j2+1;
            end
            x1 = x(1:2:end); % for tile 1 all trials
            x2 = x(2:2:end); % for tile 2 all trials
            out_distractor = union(find(x1 == 0), find(x2 == 0)); % to later discard distractor trials
        elseif convertCharsToStrings(b_data(i).name) == "random_match" % we do not include it, but we need to discard random trials
            out_random = find(x == 1);
        elseif convertCharsToStrings(b_data(i).name) == "board_size" && n_subject == 14 % subject 14 does not have board size as predictor
            n_ic = j1;
        elseif convertCharsToStrings(b_data(i).name) == "n_since_pair"
            x_1t = x(1:2:end, :);
            % include interaction term n_since_pair*match
            match = b_data(1).x;
            x_1tile = [x_1tile, x_1t.*match];
            name_x1{j1} = ['n-since-pair*match']; j1 = j1+1; 
        elseif convertCharsToStrings(b_data(i).name) == "unseen_unmatch" % we do not include it
            n_sub
        elseif convertCharsToStrings(b_data(i).name) == "n_since_last_click";
            % create from n_since_last_click, the first_click bariable
            x_1t = x(1:2:end, :);
            x_never_click_1 = zeros(size(x_1t));
            x_never_click_1(x_1t == 0) = 1;
            x_2t = x(2:2:end, :);
            x_never_click_2 = zeros(size(x_2t));
            x_never_click_2(x_2t == 0) = 1;
            x_1tile = [x_1tile, x_1t, x_never_click_1];            
            x_2tile = [x_2tile, x_2t, x_never_click_2];
            name_x1{j1} = ['n-since-last-click']; j1 = j1+1;
            name_x2{j2} = ['n-since-last-click']; j2 = j2+1;
            name_x1{j1} = ['first-click']; j1 = j1+1;
            name_x2{j2} = ['first-click']; j2 = j2+1;
        else
            % for the rest of the predictors
            if size(x, 1) == max_tiles % for variables dependent on the tile #
                x_1tile = [x_1tile, x(1:2:end, :)]; % only consider for the 1st tile
                x_2tile = [x_2tile, x(2:2:end, :)]; % only consider for the 2nd tile
            else % for variables only dependent on the trial
                x_1tile = [x_1tile, x]; 
                x_2tile = [x_2tile, x]; 
            end
            name = join(split(b_data(i).name, '_'), '-');
            name_x1{j1} = name{1}; name_x2{j2} = name{1};
            j1 = j1 + 1;j2 = j2 + 1;
        end  
    end
    
    % Add next-match predictor
    next_match = b_data(1).x;
    next_match = [next_match(2:end); 0];
    x_1tile(:, j1) = next_match;
    name_x1{j1} = 'next-match';
    x_2tile(:, j2) = next_match;
    name_x2{j2} = 'next-match';

    % Remove outliers
    out = union(out_random, out_distractor);
    out = union(out,out_rt);
    x_1tile(out, :) = [];
    x_2tile(out, :) = [];
    
    % reorder variables, so next-match is not at the end
    order_1 = [1:size(x_1tile, 2)];
    order_1(7:end) = order_1(6:end-1); order_1(6) = size(x_1tile, 2);
    order_2 = [1:size(x_2tile, 2)];
    order_2(6:end) = order_2(5:end-1); order_2(5) = size(x_2tile, 2);
    
    x_1tile = x_1tile(:,order_1);
    x_2tile = x_2tile(:,order_2);
    name_x1_new = {};
    for i_name = 1:length(name_x1);
        name_x1_new{i_name} = name_x1{order_1(i_name)};
    end
    name_x1 = name_x1_new;
    name_x2_new = {};
    for i_name = 1:length(name_x2);
        name_x2_new{i_name} = name_x2{order_2(i_name)};
    end
    name_x2 = name_x2_new;

    % To save for all subjects
    x_1tile_all{n_subject} = x_1tile;
    x_2tile_all{n_subject} = x_2tile;

    % Plot pair-wise correlations tile 1
    figure(1)
    R0 = corrcoef(x_1tile);
    J = customcolormap_preset('red-white-blue');
    h = heatmap(name_x1,name_x1,R0,'Colormap',J)
    caxis([-1 1])
    ax = gca;
    ax.FontSize = 11;
    ax.Units = 'inches';
    ax.Position = [2 2 2 2];
    title('tile 1 '+n_sub)
    saveas(1, fullfile(savefolder,'tile1_corr_subject_'+n_sub), 'fig')
    close(figure(1))

    % Plot VIF tile 1
    V=diag(inv(R0))'; 
    figure(2)
    bar(1:length(R0), V,'FaceColor',[0.5 0.5 0.5])
    axis tight
    xlabel('Predictor Variables')
    ylabel('VIF')
    title('tile 1 '+n_sub)
    xticks(1:length(R0))
    xticklabels(name_x1);
    hold on
    plot([0 length(R0)+1],[4 4],'--r')
    ax = gca;
    ax.FontSize = 20;
    saveas(2, fullfile(savefolder,'tile1_VIF_subject_'+n_sub), 'fig')
    close(figure(2))
    for i_vif=1:length(V)
        names_vif = join(split(name_x1{i_vif},'-'),'_');
        names_vif = join(split(names_vif{1},'*'),'_');
        VIF_tile1(n_subject).(names_vif{1}) = V(i_vif);
    end  
    
    % Plot pair-wise correlations tile 2
    figure(3)
    R0 = corrcoef(x_2tile);
    J = customcolormap_preset('red-white-blue');
    h = heatmap(name_x2,name_x2,R0,'Colormap',J);
    caxis([-1 1])
    ax = gca;
    ax.FontSize = 11;
    ax.Units = 'inches';
    ax.Position = [2 2 2 2];
    title('tile 2 '+n_sub)
    saveas(3, fullfile(savefolder,'tile2_corr_subject_'+n_sub), 'fig')
    close(figure(3))

    % Plot VIF tile 2
    V=diag(inv(R0))'; 
    figure(4)
    bar(1:length(R0), V,'FaceColor',[0.5 0.5 0.5])
    axis tight
    xlabel('Predictor Variables')
    ylabel('VIF')
    title('tile 2 '+n_sub)
    xticks(1:length(R0))
    xticklabels(name_x2);
    hold on
    plot([0 length(R0)+1],[4 4],'--r')
    ax = gca;
    ax.FontSize = 20;
    saveas(4, fullfile(savefolder,'tile2_VIF_subject_'+n_sub), 'fig')
    close(figure(4))
    for i_vif=1:length(V)
        names_vif = join(split(name_x2{i_vif},'-'),'_');
        names_vif = join(split(names_vif{1},'*'),'_');
        VIF_tile2(n_subject).(names_vif{1}) = V(i_vif);
    end

end

%% Plot VIF tile 1

% average VIF
figure(1)
mean_VIF = [];
names = fieldnames(VIF_tile1);
for i=2:length(names)
    mean_VIF(i-1) = mean([VIF_tile1.(names{i})]);
end
% bar plot
bar(1:length(mean_VIF),mean_VIF,'FaceColor',[0.7 0.7 0.7])
ylabel('VIF')
title('tile 1')
xticks(1:length(mean_VIF))
xticklabels(name_x1);
ax = gca;
ax.FontSize = 11;
% plot each subject
hold on
for i=2:length(names)
    predictor = [VIF_tile1.(names{i})];
    scatter((i-1)*ones(size([1:length(predictor)])), predictor,5,'k')
end
ylim([1 3])
set(gca,'fontsize', 11,'TickDir','out','FontName','Arial','box','off')
ax = gca;
ax.Units = 'inches';
ax.Position = [1 2 3 1];

%% Plot VIF tile 2

% average VIF
figure(2)
mean_VIF = [];
names = fieldnames(VIF_tile2);
for i=2:length(names)
    mean_VIF(i-1) = mean([VIF_tile2.(names{i})]);
end
% bar plot
bar(1:length(mean_VIF),mean_VIF,'FaceColor',[0.7 0.7 0.7])
ylabel('VIF')
title('tile 2')
xticks(1:length(mean_VIF))
xticklabels(name_x2);
ax = gca;
ax.FontSize = 11;
% plot each subject
hold on
for i=2:length(names)
    predictor = [VIF_tile2.(names{i})];
    scatter((i-1)*ones(size([1:length(predictor)])), predictor,5,'k')
end
ylim([1 3])
set(gca,'fontsize', 11,'TickDir','out','FontName','Arial','box','off')
ax = gca;
ax.Units = 'inches';
ax.Position = [1 2 3 1];

%% Plot average correlation

% include nans in subject 14 board size, if this subject is considered

if plot_14
    data_14 = x_1tile_all{idx_14};
    data_14(:,9:15) = data_14(:,8:14);
    data_14(:,8) = nan;
    x_1tile_all{idx_14} = data_14;
    
    data_14 = x_2tile_all{idx_14};
    data_14(:,8:14) = data_14(:,7:13);
    data_14(:,7) = nan;
    x_2tile_all{idx_14} = data_14;
end

%% Plot average over average correlation

% TILE 1
R0 = [];
for j=1:length(x_1tile_all)
    x =  x_1tile_all{j};
    R0(:,:,j) = corrcoef(x);
end
R0 = nanmean(R0,3);
figure(3)
J = customcolormap_preset('red-white-blue');
h = heatmap(name_x1,name_x1,R0,'Colormap',J);
caxis([-1 1])
ax = gca;
ax.FontSize = 11;
ax.Units = 'inches';
ax.Position = [2 2 2 2];
title(['tile 1'])

% TILE 2
R0 = [];
for j=1:length(x_2tile_all)
    x =  x_2tile_all{j};
    R0(:,:,j) = corrcoef(x);
end
R0 = nanmean(R0,3);
figure(4)
J = customcolormap_preset('red-white-blue');
h = heatmap(name_x2,name_x2,R0,'Colormap',J);
caxis([-1 1])
ax = gca;
ax.FontSize = 11;
ax.Units = 'inches';
ax.Position = [2 2 2 2];
title(['tile 2'])