clc;clear
addpath(genpath('functions/functions_general'));
addpath(genpath('functions/chronux_2_12'));

%% SCRIPT TO GROUP ELECTRODES DATA BY THEIR BRAIN REGION

% It loads the data for each subject, and groups the electrodes based on
% their brain region. For each brain region, saves a .mat file with the
% 'data' struct. Fields contain:
% - region_name: name of the region
% - subject: name of the corresponding subject
% - artifacts: artifacts of all channels considered
% - power: n_trialsxn_timexn_ch, power for each channel
% - auc: n_trialsxn_ch, AUC of the gamma power for each trial
% - n_ch: channels correspoding numbers
% - number: total numer of channels
% - t_plot : vector of time

frequency_band = 'gamma';
subjects = [1:4];

folder = sprintf(['P05_group_regions_tile_2/%s/'], frequency_band)
mkdir(folder)

alphabet = "abcdefghijklmnopqrstuvwxyz";

for n_subject = subjects

    subject = n_subject;
    n_sub = string(n_subject);
    
    % load data
    load(fullfile('P00_data_behavior','b_data_subject_'+n_sub+'.mat'));
    load(fullfile('P01_TFD_chronux_tile_2',frequency_band,'P01_subject_'+n_sub+'.mat'));
    load(fullfile('P03_AUC_tile_2',frequency_band,'data_subject_'+n_sub+'.mat'));

    t_plot = t_plot_save;
    inter_1img_2img = b_data(6).x;
    
    start_sec = 0;
    end_sec = 1;
    buffer_zone_sec = 0.15; 
    base_sec = 0.4; 
    after_match_sec = 0.5;
    mean_rt = mean(inter_1img_2img);
    
    % discard buffer zone
    [~,plot_start] = min(abs(t_plot-(-base_sec-mean_rt))); 
    [~,plot_end] = min(abs(t_plot-0.9)); 
    t_plot_n = t_plot(plot_start:plot_end);
    t_plot_n = t_plot(plot_start:plot_end);
    
    random_match = b_data(2).x;
    image_category = b_data(11).x; 
    x1 = image_category(1:2:end);
    x2 = image_category(2:2:end);
    x_out = union(find(x1 == 0), find(x2 == 0));
    out_rt = [out_rt; x_out]; % remove rials with distractor
    
    artifacts = union(out_rt, find(random_match == 1));
    
    %
    regions = [X_data.region_name];
    unique_regions = unique(regions);
    channels_numbers = [X_data.n_ch];
    
    for i_region = 1:length(unique_regions)
        
        region = unique_regions(i_region);
        channels_in = find(regions == region);
        channels_in_nch = channels_numbers(channels_in);

        % to correct the name
        last = extractBetween(region,strlength(region),strlength(region));
        if ~contains(alphabet, last)
            region = split(region, last);
            region = string(region{1});
        end
    
        gamma_power = [];
        for j = 1:length(channels_in_nch)
            power = P01_power{channels_in_nch(j)};
            power = power(plot_start:plot_end, :, :);
            S_1 = squeeze(mean(power,2)); S_1 = S_1'; % average over frequency 
            gamma_power(:,:,j) = S_1;
        end
        remove = union(artifacts, [X_data(channels_in).artifacts]);
        
        file = fullfile(folder, region + ".mat");
        if exist(file)
            load(file)
            j = length(data) + 1;
            data(j).region_name = region;
            data(j).subject = subject;
            data(j).artifacts = remove;
            data(j).power = gamma_power;
            data(j).auc = [X_data(channels_in).auc];
            data(j).n_ch = channels_in_nch;
            data(j).number = length(channels_in_nch);
            data(j).t_plot = t_plot_n;
            save(file, 'data')
        else
            data = struct;
            data(1).region_name = region;
            data(1).subject = subject;
            data(1).artifacts = remove;
            data(1).power = gamma_power;
            data(1).auc = [X_data(channels_in).auc];
            data(1).n_ch = channels_in_nch;
            data(1).number = length(channels_in_nch);
            data(1).t_plot = t_plot_n;
            save(file, 'data')
        end
    
    end
end
    