function [p_model_match, tstat_match, p_model_mismatch, tstat_mismatch, p_model, tstat, board_sizes, matches] = lm_boardsize_behavior(b_data_subjects, remove1, feature, tile, remove_zeros,use_sqrt)
    
    % Test whether a predictor increases/decreases with board size, using
    % linear regression model
    
    % Input params:
    % b_data_subjects: 1xn_sub struct (n_sub:20, totla # of subjects) with
    % 12 fields corresponding to each predictor
    % remove1: 1xn_sub cell (n_sub:20, totla # of subjects), each entry
    % contains artifact trials for each subject
    % feature: char name of the predictor to be selected
    % tile: 1 or 2, for which tile to be computed
    % remove_zeros: bool, indicating whether to include zeros or not
    % use_sqrt: bool, indicating whether to use sqrt of the board size
    
    % Output params:
    % p_model_match: p-value of the LR model for match trials
    % tstat_match: t-stat of the board size LR model for match trials
    % p_model_mismatch: p-value of the LR model for mismatch trials
    % tstat_mismatch: t-stat of the board size LR model for mismatch trials
    % p_model: p-value of the LR model for all trials
    % tstat: t-stat of the board size LR model for all trials

    n_subjects = length(b_data_subjects);
    matches = [];
    board_sizes = [];
    predictors = [];

    % create data
    for n_sub=1:n_subjects
        % take
        match = b_data_subjects(n_sub).('match');
        predictor = b_data_subjects(n_sub).(feature);
        if length(match) < length(predictor)
            predictor = predictor(tile:2:end);
        end
        board = b_data_subjects(n_sub).('board_size');
        board = board(tile:2:end);

        % remove 0s, outliers, etc..
        if remove_zeros
            idx_out = find(predictor == 0);
            remove1{n_sub} = union(remove1{n_sub}, idx_out');
        end

        match(remove1{n_sub}) = []; 
        predictor(remove1{n_sub}) = []; 
        board(remove1{n_sub}) = [];

        % concat
        matches = [matches, match];
        predictors = [predictors, predictor];
        board_sizes = [board_sizes, board];
    end

    if use_sqrt
        board_sizes = sqrt(board_sizes);
    end
    
    mdl = fitlm(board_sizes(matches == 1),predictors(matches == 1));
    p_model_match = coefTest(mdl);
    p_values = mdl.Coefficients.pValue; p_model_match = p_values(2);
    tstats = mdl.Coefficients.tStat; tstat_match = tstats(2);

    mdl = fitlm(board_sizes(matches == 0),predictors(matches == 0));
    p_model_mismatch = coefTest(mdl);
    p_values = mdl.Coefficients.pValue; p_model_mismatch = p_values(2);
    tstats = mdl.Coefficients.tStat; tstat_mismatch = tstats(2);
    
    mdl = fitlm(board_sizes,predictors)
    p_model = coefTest(mdl);
    p_values = mdl.Coefficients.pValue; p_model = p_values(2);
    tstats = mdl.Coefficients.tStat; tstat = tstats(2);
end