function plot_compare_auc(predictor, auc_data, artifacts, x_name, remove_zeros)

    % IT computes a linear regression fit of the AUC vs. the indicated
    % predictor, to analyze how they covary
    % - predictor: n_trial x 1, value of the predictor for each trial
    % - auc_data: n_trial x 1, AUC of each trial
    % - artifacts: array, index of the trials to be removed
    % - x_name: char, name of the predictor to be used as x_label
    % - remove_zeros: bool, whether to remove trials where the predictor
    % equals 0

    if remove_zeros
        artifacts = union(artifacts, find(predictor == 0));
    end
    auc_data(artifacts) = [];
    predictor(artifacts) = [];

    figure(1)
    s = scatter(predictor, auc_data,1,'k','filled')

    c = polyfit(predictor,auc_data,1);
    mdl = fitlm(predictor,auc_data);
    p = mdl.Coefficients.pValue;p = p(2);
    p_copy = p;
    if p <= 0.001
        p = "p<0.001";
    else
        p = sprintf(['p=%s'], string(p));
    end
    y_est = polyval(c,predictor);
    hold on
    plot(predictor,y_est,'r-','LineWidth',1)
    lg1 = sprintf(['n=%s'], string(length(y_est)));
    lg2 = p;
    %location_legend = "northwest";
    %lgd = legend(lg1,lg2,'Location',location_legend,'FontName','Arial');
    lgd = legend(lg1,lg2,'FontName','Arial');
    lgd.FontSize = 11;
    ax = gca;
    ax.FontSize = 11;
    set(gca,'fontsize', 11,'TickDir','out','box','off')


    xlabel(x_name)
    ylabel('\gamma AUC')
end
 