function [N, X] =  plot_compare_predictor_power(predictor, power, artifacts, thrs, tile, t_plot_n, inter_1img_2img, legend_text, ylimits, lines_rt, plot_zeros)

    % Plot compare the power signal for different values of a predictor
    % inputs:
    % - predictor: n_trial x 1, predictor we want to copwer
    % - power: n_time x n_freq x n_trial, power of the signal (artifacts already removed)
    % - thrs: array of thresholds, e.g. [10,20] will take x<10, 10<=x<20, 20<=x
    % - tile: int, if plot tile 1 or 2
    % - t_plot_n: 1 x n_time, vector of time
    % - inter_1img_2img: n_trial x 1, trials' reaction time
    % - legend_text: char, text of the legend
    % - ylimits: [y_min, y_max], y-limits of the plot
    % - lines_rt: bool, if true plot the average reaction time for each group
    % - plot_zeros: bool, whether to plot trials where the predictor equals
    % 0

    % include zeros or not
    if ~plot_zeros
        artifacts = union(artifacts, find(predictor == 0));
        start = 1;
    else
        start = 0;
    end
    
    % remove artifacts
    power(:,:,artifacts) = [];
    predictor(artifacts) = [];
    mean_rt = mean(inter_1img_2img);
    inter_1img_2img(artifacts) = [];
    
    N = length(thrs) + 2; % number of groups we are going to create
    thrs = sort(thrs); % we sort them
    colormap(lines(N)) % colors
    jetcustom = lines(N);
    lgds = {};
    ss = [];
    for i=start:N-1
        if i == 0
            idx = find(predictor == 0);
            lg1 = sprintf(['first-click, n=%s'], num2str(length(idx)));
        elseif i == 1
            min_n = 0;
            max_n = thrs(i);
            idx = intersect(find(predictor>min_n), find(predictor<=max_n));
            lg1 = sprintf(['0<x<=%s, n=%s'], num2str(max_n), num2str(length(idx)));
        elseif i == N-1
            min_n = thrs(i-1);
            max_n = max(predictor)+1;
            idx = intersect(find(predictor>min_n), find(predictor<=max_n));
            lg1 = sprintf(['x>%s, n=%s'], num2str(min_n), num2str(length(idx)));
        else
            min_n = thrs(i-1);
            max_n = thrs(i);
            idx = intersect(find(predictor>min_n), find(predictor<=max_n));
            lg1 = sprintf(['%s<x<=%s, n=%s'], num2str(min_n), num2str(max_n), num2str(length(idx)));
        end

        power_plot = power(:, :, idx);

        if length(idx) == 1
            S_1 = squeeze(mean(power_plot,2)); S_1 = S_1'; % average over frequency
            mean_rt_p = S_1;
            sem_rt_p = zeros(size(S_1));
        else
            S_1 = squeeze(mean(power_plot,2)); S_1 = S_1'; % average over frequency
            mean_rt_p = mean(S_1);
            sem_rt_p = std(S_1)/sqrt(size(S_1,1));
        end
            
        s1 = shadedErrorBar(t_plot_n,mean_rt_p,sem_rt_p,'lineprops',{'Color',jetcustom(i+1,:)});
        hold on
        set(s1.edge,'LineWidth',0.01)
        s1.mainLine.LineWidth = 1;
        ss = [ss, s1.mainLine];
        if plot_zeros
            lgds{i+1} = lg1;
        else
            lgds{i} = lg1;
        end
        
        if lines_rt
            % plot mean reaction time
            m_rt = mean(inter_1img_2img(idx))
            if tile ~= 1
                m_rt = -m_rt; % plot mean reaction time 
            end
            s3 = line([m_rt,m_rt],[-2 20],'color',jetcustom(i+1,:),'linestyle','--','linewidth', 1.5);
        end
    end

    if tile == 1
        if not(lines_rt)
            s3 = line([mean_rt,mean_rt],[-2 20],'color','k','linestyle','--');
        end
        s4 = line([0,0],[-2 20],'color','k','linestyle','-');
        text_xlabel = 'Time from 1st tile (s)';
    else
        if not(lines_rt)
            s3 = line([-mean_rt,-mean_rt],[-2 20],'color','k','linestyle','--');
        end
        s4 = line([0,0],[-2 20],'color','k','linestyle','-');
        text_xlabel = 'Time to 2nd tile (s)';
    end

    xlim([t_plot_n(1) t_plot_n(end)])
    if tile == 1
        text_xlabel = 'Time from 1st tile (s)';
        loc_legend = 'northeast';
    else
        text_xlabel = 'Time to 2nd tile (s)';
        loc_legend = 'northwest';
    end
    xlabel(text_xlabel);
    ylabel('Z-scored \gamma power');
    xticks = [-2:0.5:t_plot_n(end)]; 
    set(gca,'xtick',xticks,'tickDir','out','box','off'); 

    leg = legend(ss, lgds,'Location',loc_legend,'FontName','Arial');
    leg.FontSize = 10;
    title(leg,legend_text)

    ax = gca;
    ax.FontSize = 11;

    ylim(ylimits)


end