function plot_glm_result(n_fig, tstats, p_values, p_model, coeff_names, p_value1, p_value2)

    % Function to plot the GLM t-statisitc for one channel.
    
    % Params:
    % - n_fig: int, number of the figure to be plotted
    % - tstat: array, value of the t-statistic for each predictor
    % - p_values: array, p_values associated to each predictor
    % - p_model: number, p_value of the GLM model
    % - coeff_names: cell (1 x # of predictors, each entry is the name of the corresponsing
    % predictor
    % - p_value1: first threshold, predictors with p_valu<p_value1 will
    % have a blue star on top of the corresponding bar.
    % - p_value3: first threshold, predictors with p_valu<p_value3 will
    % have a black star on top of the corresponding bar.

    figure(n_fig)
    x  = [1:length(coeff_names)];
    b = bar(x, tstats, 'FaceColor', [0.5 0.5 0.5]); % plot the tstats
    hold on
    % create starts significance
    ind_1 = find(p_values <= p_value1);
    plot(ind_1, tstats(ind_1) + 1*sign(tstats(ind_1)) - 1*(tstats(ind_1) < 0), '*', 'Color', 'b','MarkerSize',10,'LineWidth',2)
    ind_2 = intersect(find(p_values > p_value1),  find(p_values < p_value2));
    plot(ind_2, tstats(ind_2) + 1*sign(tstats(ind_2)) - 1*(tstats(ind_2) < 0), '*k','MarkerSize',10,'LineWidth',2)
    ylim([-7 7])
    xlim([0.5 18.5])
    ylabel('t-statistic')
    xticks(x)
    xticklabels(coeff_names);
    set(gca,'fontsize', 11,'TickDir','out','FontName','Arial','box','off')

    % significance of the model
    if p_model < 0.001
        p_model = "p<0.001";
    else
        p_model = sprintf(['p=%s'],num2str(p_model))
    end
    if isempty(ind_1)
        leg = legend(p_model,sprintf(['p<%s'],num2str(p_value2)));
    else
        leg = legend(p_model,sprintf(['p<%s'],num2str(p_value1)),sprintf(['p<%s'],num2str(p_value2)));
    end
    leg.FontSize = 10;
    xtickangle(60)
end