function plot_image_category(power, image_category, tile, mean_rt, t_plot, ylimits, include_distractor)
    
    % Function to plot the average power for different image categories
    % Inputs:
    % - power: n_time x n_freq x n_trial, power of the signal (artifacts already removed)
    % - image category: n_trial x 1, vector containing the image category info wrt each trial
    % - tile: 1 or 2, if plot tile one or 2
    % - mean_rt: double, mean reaction time
    % - t_plot: 1 x n_time, vector of time
    % - ylimits: [min,max], power ylimits
    % - include distractor: bool, true if also plot distractor

    if include_distractor
        start_i = 0;
    else
        start_i = 1;
    end

    if tile == 1
        text_title = '1st tile image category';
        text_xlabel = 'Time from 1st tile (s)';
        mean_rt = -mean_rt;
    else 
        text_title = '2nd tile image category';
        text_xlabel = 'Time to 2nd tile (s)';
    end

    categories = {'distractor', 'indoor', 'animal', 'food', 'person', 'vehicle'};
    colors = {[0.3010 0.7450 0.9330], [0.9290 0.6940 0.1250], [0.4660 0.6740 0.1880], [0.4940 0.1840 0.5560],  [0 0.4470 0.7410],[0.8500 0.3250 0.0980]};
   
    %colors = {[0.3010 0.7450 0.9330], [0.4660 0.6740 0.1880], [0.4940 0.1840 0.5560], [0.9290 0.6940 0.1250], [0 0.4470 0.7410],[0.8500 0.3250 0.0980]};
    lgds = {};
    ss= [];
    for i=start_i:5 % plot for each image
        idx = find(image_category == i);
        power_img = power(:, :, idx);
        S_1 = squeeze(mean(power_img,2)); S_1 = S_1'; % average over frequency
        mean_p = mean(S_1);
        sem_p = std(S_1)/sqrt(size(S_1,1));
        
        s1 = shadedErrorBar(t_plot,mean_p,sem_p,'lineprops',{'Color',colors{i+1}});
        set(s1.edge,'LineWidth',0.01)
        s1.mainLine.LineWidth = 1;
        lg1 = sprintf('%s, n=%d', categories{i+1}, length(idx));
        if include_distractor
            lgds{i+1} = lg1;
        else
            lgds{i} = lg1;
        end
        ss = [ss, s1.mainLine];
        
        
        hold on
    end
    
    lgds
    
    if tile == 1
        legend(ss, lgds,'Location','northeast','FontName','Arial')
    else
        legend(ss, lgds,'Location','northwest','FontName','Arial')
    end

    s01 = line([-mean_rt,-mean_rt],[-1 8],'color','k','linestyle','--');
    s02 = line([0,0],[-1 8],'color','k','linestyle','-');
    s01.Annotation.LegendInformation.IconDisplayStyle = 'off';
    s02.Annotation.LegendInformation.IconDisplayStyle = 'off';

    xlim([t_plot(1) t_plot(end)])
    
    xlabel(text_xlabel);
    ylabel('Z-scored \gamma power');

    title('all')

    ylim(ylimits)

    title(text_title)

    ax = gca;
    ax.FontSize = 11;

end