function plot_match_spectrogram(power, artifacts, match, random_match, t_plot, f, ylimits, tile, inter_1img_2img)

    % Average spectrogram of match and mismatch trials
    % - power: n_time x n_freq x n_trials : power or all trials
    % - artifacts: array, index of trials to be removed
    % - match: array n_trials x 1, value of 1 if match trial, 0 otherwise
    % - random_match: array n_trials x 1, value of 1 if random match, 0 otherwise
    % - t_plot: 1 x n_time, vector of time
    % - f: vector of frequencies
    % - ylimits: y-limits of the plots
    % - tile: 1 or 2
    % - inter_1img_2img: array n_trials x 1, reaction time
    
    addpath(genpath('../functions_general'));
    addpath(genpath('../chronux_2_12'));

    match(artifacts) = [];
    random_match(artifacts) = [];
    inter_1img_2img(artifacts) = [];
    power(:,:,artifacts) = [];
    
    mean_rt = mean(inter_1img_2img);

    % power match not random
    idx_m = intersect(find(match == 1), find(random_match == 0));
    power_match_0 = power(:, :, idx_m);
    S_match_heat = mean(power_match_0,3); % average over trials

    % mismatch
    idx_u = find(match == 0);
    power_mismatch_0 = power(:, :, idx_u);
    S_mismatch_heat = mean(power_mismatch_0,3); % average over trials
    
    
    if tile == 1
        location_legend = 'northeast';
        mean_rt = -mean_rt;
        text_xlabel = 'Time from 1st tile (s)';
    else
        location_legend = 'northwest';
        text_xlabel = 'Time to 2nd tile (s)';
    end
    
    figure(1)
    plot_matrix(S_match_heat,t_plot,f,'n') 
    xlabel(text_xlabel);
    ylabel('Frequency (Hz)');
    title('Match');
    xticks = [-2:0.5:t_plot(end)];
    colormap('jet')
    xlim([t_plot(1) t_plot(end)]);
    cb = colorbar; 
    ylabel(cb,'Z-scored Power');
    caxis(ylimits)
    xlim([t_plot(1) t_plot(end)]);
    line([-mean_rt,-mean_rt],[f(1) f(end)],'color',[1 1 1],'linestyle','--','LineWidth',1);
    line([0,0],[f(1) f(end)],'color',[1 1 1],'linestyle','-','LineWidth',1);
    %line([t_plot(1),t_plot(end)],[8 8],'color',[1 1 1],'linestyle','-','LineWidth',1);    
    %line([t_plot(1),t_plot(end)],[14 14],'color',[1 1 1],'linestyle','-','LineWidth',1);
    set(gca,'fontsize', 11,'xtick',xticks,'TickDir','out','FontName','Arial','box','off')
    ax = gca;
    ax.FontSize =  11;


    figure(2)
    plot_matrix(S_mismatch_heat,t_plot,f,'n') 
    xlabel(text_xlabel);
    ylabel('Frequency (Hz)');
    title('Mismatch');
    colormap('jet')
    xlim([t_plot(1) t_plot(end)]);
    cb = colorbar; 
    ylabel(cb,'Z-scored Power');
    caxis(ylimits)
    xlim([t_plot(1) t_plot(end)]);
    line([-mean_rt,-mean_rt],[f(1) f(end)],'color',[1 1 1],'linestyle','--','LineWidth',1);
    line([0,0],[f(1) f(end)],'color',[1 1 1],'linestyle','-','LineWidth',1);
    %line([t_plot(1),t_plot(end)],[30 30],'color',[1 1 1],'linestyle','-','LineWidth',1);    
    %line([t_plot(1),t_plot(end)],[14 14],'color',[1 1 1],'linestyle','-','LineWidth',1);
    set(gca,'fontsize', 11,'xtick',xticks,'TickDir','out','FontName','Arial','box','off')
    ax = gca;
    ax.FontSize = 11;


end