function plot_raster_match(power, artifacts, match, random_match, inter_1img_2img, t_plot, ylimits, tile, equalization, rt_diff, order, pred_order, plot_predictor_values, name_predictor)
    
    % Plot 2 raster plots: one considering all match trials and one
    % considering mismatch trials
    % - power: n_time x n_freq x n_trials : power or all trials
    % - match: array n_trials x 1, value of 1 if match trial, 0 otherwise
    % - random_match: array n_trials x 1, value of 1 if random match, 0 otherwise
    % - inter_1img_2img: array n_trials x 1, reaction time
    % - t_plot: 1 x n_time, vector of time
    % - ylimitss: y-limits of the plots
    % - tile: 1 or 2
    % - equalization: bool, random equalization of # match and mismatch trials if true
    % - rt_diff: bool, equalization of RT and # match and mismatch trials if true
    % - order: bool, true if order trial by an specified predictor
    % - pred_order: n_trials x 1, value of the predictor used to order the
    % trials
    % - plot_predictor_values: array, at these values we plot a yellow line
    % - name_predictor: char, name of the predictor used to order the
    % trials
    
    % Remove artifacts
    power(:,:,artifacts) = [];
    match(artifacts) = [];
    random_match(artifacts) = [];
    inter_1img_2img_iChannel = inter_1img_2img;
    inter_1img_2img_iChannel(artifacts) = [];
    
    % Order samples by the predictor selected
    if order
        pred_order(artifacts) = [];
        [pred_order,idx_order] = sort(pred_order);
        power = power(:,:,idx_order); match = match(idx_order); random_match = random_match(idx_order);
    end
    ind_match = intersect(find(match==1),find(random_match==0));
    ind_unmatch = find(match==0);
    
    
    % Equalization # of samples wo time equalization
    if equalization
        if length(ind_match) < length(ind_unmatch)
            rng(1)
            ind_unmatch = randsample(ind_unmatch, length(ind_match));
        else
            rng(1)
            ind_match = randsample(ind_match, length(ind_unmatch));
        end
    end
    
    % Equalization # of samples w time equalization
    if rt_diff
        if length(ind_unmatch) > length(ind_match)
            rt_match = inter_1img_2img(ind_match);
            rt_unmatch = inter_1img_2img(ind_unmatch);
            m_match = mean(rt_match);
            diff_val = abs(rt_unmatch - m_match);
            [b, indx] = sort(diff_val);
            indx = indx(1:length(rt_match));
            ind_unmatch = ind_unmatch(indx);
        else
            rng(1)
            ind_match = randsample(ind_match, length(ind_unmatch));
        end
    end
    ind_match = sort(ind_match); ind_unmatch = sort(ind_unmatch);
    
    if order
        pred_match = pred_order(ind_match);
        pred_unmatch = pred_order(ind_unmatch);
    end
    
    % Average
    S_1 = squeeze(mean(power(:,:,ind_match),2)); S_1 = S_1'; % average over frequency
    S_2 = squeeze(mean(power(:,:,ind_unmatch),2)); S_2 = S_2'; % average over frequency
    
    rt_match = mean(inter_1img_2img_iChannel(ind_match));
    rt_unmatch = mean(inter_1img_2img_iChannel(ind_unmatch));
    if tile == 1
        text_x = 'Time from 1st tile (s)';
    else
        rt_match = -rt_match; rt_unmatch = -rt_unmatch;
        text_x = 'Time to 2nd tile (s)';
    end
    [~,rt_match_tick] = min(abs(t_plot-(rt_match)));  
    [~,rt_unmatch_tick] = min(abs(t_plot-(rt_unmatch))); 
    [~,time_click] = min(abs(t_plot-0));  
    
    %[~,plot_end] = min(abs(t_plot-((mean(inter_1img_2img_iChannel(union(ind_match,ind_unmatch)))))-0.5)); 
    r_end = t_plot(end);
    r_start = t_plot(1);
    options = [-2:0.5:2.5];
    [~,idx] = min(abs(options-r_start));
    r_start = options(idx);
    xpoints =r_start:0.5:r_end;
    for i = 1:length(xpoints)
        [~,xticks(i)] = min(abs(t_plot-xpoints(i))); 
    end

    % Plot raster match
    figure(1);
    image(S_1,'CDataMapping','scaled') 
    cb = colorbar;
    colormap('copper'); 
    caxis(ylimits)    
    titleName = sprintf('Match');
    title(titleName); 
    names = string(xpoints);
    hold on;
    line([rt_match_tick,rt_match_tick],[length(ind_match) 1],'Color','w','linestyle','--','LineWidth',1)
    line([time_click,time_click],[length(ind_match) 1],'Color','w','linestyle','-','LineWidth',1)
    xlabel(text_x);
    ylabel('Trial')
    hold on;
    ylabel(cb,'Z-scored \gamma Power');
    set(gca,'fontsize', 8,'xtick',xticks,'xticklabel',names,'TickDir','out','Box','off')
    
    % include lines indicating predictors values
    if order
        yyaxis right
        yticks_p = [];
        for i=1:length(plot_predictor_values)
            idx = max(find(pred_match < plot_predictor_values(i))); % find idc limit
            yticks_p = [yticks_p, idx+1];
        end
        yticks_p_flip = flip(1-yticks_p/length(pred_match)); % normalize and flip so the axes match
        plot_pred = flip(plot_predictor_values); % normalize and flip
        for i=1:length(yticks_p_flip)
            line([1 size(S_1, 2)], [yticks_p_flip(i) yticks_p_flip(i)], 'Color','y','linestyle','-','LineWidth',1)
        end
        set(gca,'fontsize', 8,'ytick',yticks_p_flip,'yticklabel',plot_pred,'YColor','k')
        ylim([0 1])
        ylabel(name_predictor, 'Rotation', -90,'VerticalAlignment','middle')
        ax = gca;
        ax.FontSize = 8;
    end

    % Plot raster mismatch
    figure(2);
    image(S_2,'CDataMapping','scaled') 
    cb = colorbar;
    colormap('copper'); 
    caxis(ylimits)    
    titleName = sprintf('Mismatch');
    title(titleName); 
    names = string(xpoints);
    hold on;
    line([rt_unmatch_tick,rt_unmatch_tick],[length(ind_unmatch) 1],'Color','w','linestyle','--','LineWidth',1)
    line([time_click,time_click],[length(ind_unmatch) 1],'Color','w','linestyle','-','LineWidth',1)
    xlabel(text_x);
    ylabel('Trial')
    hold on;
    ylabel(cb,'Z-scored \gamma Power');
    set(gca,'fontsize', 8,'xtick',xticks,'xticklabel',names,'TickDir','out','Box','off')
    ax = gca;
    ax.FontSize = 8;
    
    % include lines indicating predictors values
    if order
        yyaxis right
        yticks_p = [];
        for i=1:length(plot_predictor_values)
            idx = max(find(pred_unmatch < plot_predictor_values(i))); % find idc limit
            yticks_p = [yticks_p, idx+1];
        end
        yticks_p_flip = flip(1-yticks_p/length(pred_unmatch)); % normalize and flip so the axes match
        plot_preds = flip(plot_predictor_values); % normalize and flip
        for i=1:length(yticks_p_flip)
            line([1 size(S_2, 2)], [yticks_p_flip(i) yticks_p_flip(i)], 'Color','y','linestyle','-','LineWidth',1.5)
        end
        set(gca,'fontsize', 8,'ytick',yticks_p_flip,'yticklabel',plot_pred,'YColor','k')
        ylim([0 1])
        ylabel(name_predictor, 'Rotation', -90,'VerticalAlignment','middle')
        ax = gca;
        ax.FontSize = 8;
    end

end