function plot_raster_reverse(power, artifacts, random_match, inter_1img_2img, t_plot, ylimits, tile, order, pred_order, plot_predictor_values, name_predictor)
    
    % Plot raster: plot all trials
    % - power: n_time x n_freq x n_trials : power or all trials
    % - random_match: array n_trials x 1, value of 1 if random match, 0 otherwise
    % - inter_1img_2img: array n_trials x 1, reaction time
    % - t_plot: 1 x n_time, vector of time
    % - ylimitss: y-limits of the plots
    % - tile: 1 or 2
    % - order: bool, true if order trial by an specified predictor
    % - pred_order: n_trials x 1, value of the predictor used to order the
    % trials
    % - plot_predictor_values: array, at these values we plot a yellow line
    % - name_predictor: char, name of the predictor used to order the
    % trials
    
    % Remove artifacts
    artifacts = union(artifacts, find(random_match == 1));
    power(:,:,artifacts) = [];
    inter_1img_2img_iChannel = inter_1img_2img;
    inter_1img_2img_iChannel(artifacts) = [];
    
    % Order samples by the predictor selected
    if order
        pred_order(artifacts) = [];
        [pred_order,idx_order] = sort(pred_order, 'descend');
        power = power(:,:,idx_order); 
    end
    
    % Average
    S_1 = squeeze(mean(power,2)); S_1 = S_1'; % average over frequency
    
    RT = mean(inter_1img_2img_iChannel);

    if tile == 1
        text_x = 'Time from 1st tile (s)';
    else
        RT = -RT; 
        text_x = 'Time to 2nd tile (s)';
    end
    [~,RT_tick] = min(abs(t_plot-(RT)));  
    [~,time_click] = min(abs(t_plot-0));  
    
    %[~,plot_end] = min(abs(t_plot-((mean(inter_1img_2img_iChannel(union(ind_match,ind_unmatch)))))-0.5)); 
    r_end = t_plot(end);
    r_start = t_plot(1);
    options = [-2:0.5:2.5];
    [~,idx] = min(abs(options-r_start));
    r_start = options(idx);
    xpoints =r_start:0.5:r_end;
    for i = 1:length(xpoints)
        [~,xticks(i)] = min(abs(t_plot-xpoints(i))); 
    end

    % Plot raster
    figure(1);
    image(S_1,'CDataMapping','scaled') 
    cb = colorbar;
    colormap('copper'); 
    caxis(ylimits)    
    names = string(xpoints);
    hold on;
    line([RT_tick,RT_tick],[size(S_1,1) 1],'Color','w','linestyle','--','LineWidth',1)
    line([time_click,time_click],[size(S_1,1) 1],'Color','w','linestyle','-','LineWidth',1)
    xlabel(text_x);
    ylabel('Trial')
    hold on;
    ylabel(cb,'Z-scored \gamma Power');
    set(gca,'fontsize', 8,'xtick',xticks,'xticklabel',names,'TickDir','out','Box','off')
    
    % include lines indicating predictors values
    if order
        yyaxis right
        yticks_p = [];
        for i=1:length(plot_predictor_values)
            idx = min(find(pred_order < plot_predictor_values(i))); % find idc limit
            yticks_p = [yticks_p, idx+1];
        end
        yticks_p_flip = flip(1-yticks_p/length(pred_order)); % normalize and flip so the axes match
        plot_pred = flip(plot_predictor_values); % normalize and flip
        for i=1:length(yticks_p_flip)
            line([1 size(S_1, 2)], [yticks_p_flip(i) yticks_p_flip(i)], 'Color','w','linestyle','-','LineWidth',1)
        end
        set(gca,'fontsize', 8,'ytick',yticks_p_flip,'yticklabel',plot_pred,'YColor','k')
        ylim([0 1])
        ylabel(name_predictor, 'Rotation', -90,'VerticalAlignment','middle')
        ax = gca;
        ax.FontSize = 8;
    end


end