function plot_compare_frequencies(n_fig, p_gamma, p_beta, t_plot_gamma, t_plot_beta, mean_rt, take, ylimits, text_xlabel, tile, frequency_band_1, frequency_band_2)

    % Plots the average frequency_1 power versus the average frequency_2
    % power for all trials indicated by take. 
    % - n_fig: int, number of the figure
    % - p_frequency_1: n_time1xn_fre1xn_trials, power for frequency band 1
    % - p_frequency_2: n_time2xn_fre2xn_trials, power for frequency band 2
    % - t_plot_frequency_1: 1xn_time1, time vector for frequency band 1
    % - t_plot_frequency_2: 1xn_time2, time vector for frequency band 2
    % - mean_rt: mean RT
    % - take: array, index of the trials to be considered
    % - ylimits: [y1, y2], y_limits of the plot
    % - text_xlabel: char, x-label to be used
    % - tile: int, 1 or 2
    % - frequency_band_1: char, name of the frequency band 1 (e.g. 'gamma')
    % - frequency_band_2: char, name of the frequency band 1 (e.g. 'beta')
    
    power_gamma_match = p_gamma(:, :, take);
    S_1 = squeeze(mean(power_gamma_match,2)); S_1 = S_1'; % average over frequency
    mean_1 = mean(S_1);
    sem_1 = std(S_1)/sqrt(size(S_1,1));

    power_beta_match = p_beta(:, :, take);
    S_2 = squeeze(mean(power_beta_match,2)); S_2 = S_2'; % average over frequency
    mean_2 = mean(S_2);
    sem_2 = std(S_2)/sqrt(size(S_2,1));

    t_plot = t_plot_gamma;


    figure(n_fig)
    s1 = shadedErrorBar(t_plot_gamma,mean_1,sem_1,'lineprops',{'Color',[0.6350, 0.0780, 0.1840]});
    set(s1.edge,'LineWidth',0.01)
    s1.mainLine.LineWidth = 1;
    hold on;
    s2 = shadedErrorBar(t_plot_beta,mean_2,sem_2,'lineprops',{'Color',[0, 0.4470, 0.7410]});  
    set(s2.edge,'LineWidth',0.01)
    s2.mainLine.LineWidth = 1;

    if tile == 1
        mean_rt = -mean_rt;
    end
    s3 = line([-mean_rt,-mean_rt],[-4 50],'color','k','linestyle','--');
    s4 = line([0,0],[-4 50],'color','k','linestyle','-');
    s3.Annotation.LegendInformation.IconDisplayStyle = 'off';
    s4.Annotation.LegendInformation.IconDisplayStyle = 'off';

    xlim([t_plot(1) t_plot(end)])
    xlabel(text_xlabel);
    ylabel('Power');
    lg1 = ['\' frequency_band_1 ' power, n=' num2str(length(take))];
    lg2 = ['\' frequency_band_2 ' power, n=' num2str(length(take))]; 

    if tile == 1
        location_legend = 'northeast';
    else
        location_legend = 'northwest';
    end
    lgd = legend([s1.mainLine,s2.mainLine],{lg1,lg2},'FontSize',10,'Location',location_legend,'FontName','Arial');
    lgd.FontSize = 10;

    ylim(ylimits)
    xlim([t_plot(1) t_plot(end)])

    ax = gca;
    ax.FontSize = 10;
    xticks =[-1.5:0.5:t_plot(end)];
    set(gca,'xtick',xticks,'tickDir','out','box','off');

end