function plot_compare_frequencies_new(n_fig, p_frequency_1, p_frequency_2, t_plot_frequency_1, t_plot_frequency_2, mean_rt, take, ylimits_frequency_1, ylimits_frequency_2, text_xlabel, tile, frequency_band_1, frequency_band_2)

    % Plots the average frequency_1 power versus the average frequency_2
    % power for all trials indicated by take. It uses different y-axis for
    % each frequency.
    % - n_fig: int, number of the figure
    % - p_frequency_1: n_time1xn_fre1xn_trials, power for frequency band 1
    % - p_frequency_2: n_time2xn_fre2xn_trials, power for frequency band 2
    % - t_plot_frequency_1: 1xn_time1, time vector for frequency band 1
    % - t_plot_frequency_2: 1xn_time2, time vector for frequency band 2
    % - mean_rt: mean RT
    % - take: array, index of the trials to be considered
    % - ylimits_frequency_1: [y1, y2], y_limits of the plot for the
    % frequency band 1
    % - ylimits_frequency_2: [y1, y2], y_limits of the plot for the
    % frequency band 2
    % - text_xlabel: char, x-label to be used
    % - tile: int, 1 or 2
    % - frequency_band_1: char, name of the frequency band 1 (e.g. 'gamma')
    % - frequency_band_2: char, name of the frequency band 1 (e.g. 'beta')
    
    power_frequency_1_match = p_frequency_1(:, :, take);
    S_1 = squeeze(mean(power_frequency_1_match,2)); S_1 = S_1'; % average over frequency
    mean_1 = mean(S_1);
    sem_1 = std(S_1)/sqrt(size(S_1,1));

    power_frequency_2_match = p_frequency_2(:, :, take);
    S_2 = squeeze(mean(power_frequency_2_match,2)); S_2 = S_2'; % average over frequency
    mean_2 = mean(S_2);
    sem_2 = std(S_2)/sqrt(size(S_2,1));

    t_plot = t_plot_frequency_1;


    figure(n_fig)
    hold on;

    yyaxis left

    mainLineColor=[0.6350, 0.0780, 0.1840];
    edgeColor=mainLineColor+(1-mainLineColor)*0.55;
    uE=mean_1+sem_1;
    lE=mean_1-sem_1;
    yP=[lE,fliplr(uE)];
    x = t_plot_frequency_1;
    xP=[x,fliplr(x)];
    ylabel(['\' frequency_band_1 ' power']);
    pt=patch(xP,yP,1);
    patchColor=mainLineColor;
    set(pt,'facecolor',patchColor,'edgecolor','none','facealpha',0.2)
    plot(x,lE,'-','color',edgeColor);
    plot(x,uE,'-','color',edgeColor);
    s1 = plot(t_plot_frequency_1,mean_1,'-','LineWidth',1,'Color',[0.6350, 0.0780, 0.1840])

    hold on;
    yyaxis right

    mainLineColor= [0, 0.4470, 0.7410]; %[0.9290 0.6940 0.1250];
    edgeColor=mainLineColor+(1-mainLineColor)*0.55;
    uE=mean_2+sem_2;
    lE=mean_2-sem_2;
    yP=[lE,fliplr(uE)];
    x = t_plot_frequency_2;
    xP=[x,fliplr(x)];
    ylabel(['\' frequency_band_2 ' power']);
    pt=patch(xP,yP,1);
    patchColor=mainLineColor;
    set(pt,'facecolor',patchColor,'edgecolor','none','facealpha',0.2)
    plot(x,lE,'-','color',edgeColor);
    plot(x,uE,'-','color',edgeColor);
    s2 = plot(t_plot_frequency_2,mean_2,'-','LineWidth',1,'Color',[0, 0.4470, 0.7410]) %[0.9290 0.6940 0.1250]

    ax = gca;
    ax.YAxis(1).Color = [0.6350, 0.0780, 0.1840]; 
    ax.YAxis(2).Color = [0, 0.4470, 0.7410]; %[0.9290 0.6940 0.1250];

    if tile == 1
        mean_rt = -mean_rt;
    end
    s3 = line([-mean_rt,-mean_rt],[-4 50],'color','k','linestyle','--');
    s4 = line([0,0],[-4 50],'color','k','linestyle','-');
    hold on
    s3.Annotation.LegendInformation.IconDisplayStyle = 'off';
    s4.Annotation.LegendInformation.IconDisplayStyle = 'off';

    xlim([t_plot(1) t_plot(end)])
    xlabel(text_xlabel);

    lg1 = ['\' frequency_band_1 ' power, n=' num2str(length(take))];
    lg2 = ['\' frequency_band_2 'power, n=' num2str(length(take))]; 

    if tile == 1
        location_legend = 'northeast';
    else
        location_legend = 'northwest';
    end
    lgd = legend([s1,s2],{lg1,lg2},'FontSize',10,'Location',location_legend,'FontName','Arial');
    lgd.FontSize = 10;

    ax = gca;
    ax.FontSize = 10;
    xticks =[-1.5:0.5:t_plot(end)];
    ax.YAxis(1).Limits = ylimits_frequency_1;
    ax.YAxis(2).Limits = ylimits_frequency_2;
    set(gca,'TickDir','out')

end